var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

import fetch from 'isomorphic-fetch';

import { getStoredAuthToken } from '../authorization';
import { apiUrl } from '../environment';

import '../dataset/reducer';


import { transformQueryToApi } from './apiHelper';

import { transformFormQueryToApi } from './apiExternalFormsHelper';

function fetchJsonUnauthorized(url, request) {
  var rawBody = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;

  var finalRequest = request ? _extends({}, request, {
    body: rawBody ? request.body : JSON.stringify(request.body),
    headers: _extends({
      "Accept": "application/json",
      "Content-Type": "application/json"
    }, request.headers)
  }) : {
    method: "GET",
    headers: {
      "Accept": "application/json"
    }
  };

  return fetch(url, finalRequest).then(function (response) {
    if (response.status >= 200 && response.status < 300) return response.json().catch(function (e) {
      return e;
    }); // Also handle empty responses
    else
      // Reject other status
      return response.json().then(Promise.reject.bind(Promise));
  }, function (error) {
    return Promise.reject(error);
  } // Network or connection failure
  );
}

function fetchJson(url, request) {
  var rawBody = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;

  var authToken = getStoredAuthToken() || '';
  var finalRequest = _extends({}, request || {}, {
    headers: _extends({
      "Authorization": 'Bearer ' + authToken
    }, request && request.headers || {})
  });

  return fetchJsonUnauthorized(url, finalRequest, rawBody);
}

export function getFrontendConfig() {
  return fetchJson(apiUrl() + '/config/frontend');
}

export function getDatasets() {
  return fetchJson(apiUrl() + '/datasets');
}

export function postResults(datasetId, file) {
  return new Promise(function (resolve) {
    var reader = new FileReader();

    reader.onload = function (evt) {
      var fileContent = evt.target.result;

      resolve(fileContent);
    };

    reader.readAsText(file);
  }).then(function (results) {
    var rawBody = true;

    return fetchJson(apiUrl() + ('/datasets/' + datasetId + '/import'), {
      method: "POST",
      body: results,
      headers: {
        "Content-Type": "text/csv"
      }
    }, rawBody);
  });
};

export var getConcepts = function getConcepts(datasetId) {
  return fetchJson(apiUrl() + ('/datasets/' + datasetId + '/concepts'));
};

export var getConcept = function getConcept(datasetId, conceptId) {
  return fetchJson(apiUrl() + ('/datasets/' + datasetId + '/concepts/' + conceptId));
};

// Same signature as postFormQueries
export function postQueries(datasetId, query, queryType, version) {
  // Transform into backend-compatible format
  var body = transformQueryToApi(query, queryType, version);

  return fetchJson(apiUrl() + ('/datasets/' + datasetId + '/queries'), {
    method: "POST",
    body: body
  });
}

export function deleteQuery(datasetId, queryId) {
  return fetchJson(apiUrl() + ('/datasets/' + datasetId + '/queries/' + queryId), {
    method: 'DELETE'
  });
}

export function getQuery(datasetId, queryId) {
  return fetchJson(apiUrl() + ('/datasets/' + datasetId + '/queries/' + queryId));
}

// Same signature as postQueries, plus a form query transformator
export function postFormQueries(datasetId, query, queryType, version, formQueryTransformation) {
  // Transform into backend-compatible format
  var body = transformFormQueryToApi(query, version, formQueryTransformation);

  return fetchJson(apiUrl() + ('/datasets/' + datasetId + '/form-queries'), {
    method: "POST",
    body: body
  });
}

export function deleteFormQuery(datasetId, queryId) {
  return fetchJson(apiUrl() + ('/datasets/' + datasetId + '/form-queries/' + queryId), {
    method: 'DELETE'
  });
}

export function getFormQuery(datasetId, queryId) {
  return fetchJson(apiUrl() + ('/datasets/' + datasetId + '/form-queries/' + queryId));
}

export function getStoredQueries(datasetId) {
  return fetchJson(apiUrl() + ('/datasets/' + datasetId + '/stored-queries'));
}

export function getStoredQuery(datasetId, queryId) {
  return fetchJson(apiUrl() + ('/datasets/' + datasetId + '/stored-queries/' + queryId));
}

export function deleteStoredQuery(datasetId, queryId) {
  return fetchJson(apiUrl() + ('/datasets/' + datasetId + '/stored-queries/' + queryId), {
    method: 'DELETE'
  });
}

export function patchStoredQuery(datasetId, queryId, attributes) {
  return fetchJson(apiUrl() + ('/datasets/' + datasetId + '/stored-queries/' + queryId), {
    method: 'PATCH',
    body: attributes
  });
}

export function postPrefixForSuggestions(datasetId, conceptId, tableId, filterId, text) {
  return fetchJson(apiUrl() + ('/datasets/' + datasetId + '/concepts/' + conceptId) + ('/tables/' + tableId + '/filters/' + filterId + '/autocomplete'), {
    method: 'POST',
    body: { text: text }
  });
};

export function postConceptsListToResolve(datasetId, conceptId, concepts) {
  return fetchJson(apiUrl() + ('/datasets/' + datasetId + '/concepts/' + conceptId + '/resolve'), {
    method: 'POST',
    body: { concepts: concepts }
  });
};

export function postConceptFilterValuesResolve(datasetId, conceptId, tableId, filterId, values) {
  return fetchJson(apiUrl() + ('/datasets/' + datasetId + '/concepts/' + conceptId) + ('/tables/' + tableId + '/filters/' + filterId + '/resolve'), {
    method: 'POST',
    body: { values: values }
  });
};

export var searchConcepts = function searchConcepts(datasetId, query, limit) {
  return fetchJson(apiUrl() + ('/datasets/' + datasetId + '/concepts/search'), {
    method: 'POST',
    body: {
      query: query,
      limit: limit || 50
    }
  });
};
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(fetchJsonUnauthorized, 'fetchJsonUnauthorized', '/home/travis/build/bakdata/conquery/frontend/lib/js/api/api.js');
  reactHotLoader.register(fetchJson, 'fetchJson', '/home/travis/build/bakdata/conquery/frontend/lib/js/api/api.js');
  reactHotLoader.register(getFrontendConfig, 'getFrontendConfig', '/home/travis/build/bakdata/conquery/frontend/lib/js/api/api.js');
  reactHotLoader.register(getDatasets, 'getDatasets', '/home/travis/build/bakdata/conquery/frontend/lib/js/api/api.js');
  reactHotLoader.register(postResults, 'postResults', '/home/travis/build/bakdata/conquery/frontend/lib/js/api/api.js');
  reactHotLoader.register(getConcepts, 'getConcepts', '/home/travis/build/bakdata/conquery/frontend/lib/js/api/api.js');
  reactHotLoader.register(getConcept, 'getConcept', '/home/travis/build/bakdata/conquery/frontend/lib/js/api/api.js');
  reactHotLoader.register(postQueries, 'postQueries', '/home/travis/build/bakdata/conquery/frontend/lib/js/api/api.js');
  reactHotLoader.register(deleteQuery, 'deleteQuery', '/home/travis/build/bakdata/conquery/frontend/lib/js/api/api.js');
  reactHotLoader.register(getQuery, 'getQuery', '/home/travis/build/bakdata/conquery/frontend/lib/js/api/api.js');
  reactHotLoader.register(postFormQueries, 'postFormQueries', '/home/travis/build/bakdata/conquery/frontend/lib/js/api/api.js');
  reactHotLoader.register(deleteFormQuery, 'deleteFormQuery', '/home/travis/build/bakdata/conquery/frontend/lib/js/api/api.js');
  reactHotLoader.register(getFormQuery, 'getFormQuery', '/home/travis/build/bakdata/conquery/frontend/lib/js/api/api.js');
  reactHotLoader.register(getStoredQueries, 'getStoredQueries', '/home/travis/build/bakdata/conquery/frontend/lib/js/api/api.js');
  reactHotLoader.register(getStoredQuery, 'getStoredQuery', '/home/travis/build/bakdata/conquery/frontend/lib/js/api/api.js');
  reactHotLoader.register(deleteStoredQuery, 'deleteStoredQuery', '/home/travis/build/bakdata/conquery/frontend/lib/js/api/api.js');
  reactHotLoader.register(patchStoredQuery, 'patchStoredQuery', '/home/travis/build/bakdata/conquery/frontend/lib/js/api/api.js');
  reactHotLoader.register(postPrefixForSuggestions, 'postPrefixForSuggestions', '/home/travis/build/bakdata/conquery/frontend/lib/js/api/api.js');
  reactHotLoader.register(postConceptsListToResolve, 'postConceptsListToResolve', '/home/travis/build/bakdata/conquery/frontend/lib/js/api/api.js');
  reactHotLoader.register(postConceptFilterValuesResolve, 'postConceptFilterValuesResolve', '/home/travis/build/bakdata/conquery/frontend/lib/js/api/api.js');
  reactHotLoader.register(searchConcepts, 'searchConcepts', '/home/travis/build/bakdata/conquery/frontend/lib/js/api/api.js');
  leaveModule(module);
})();

;