var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

// Functions in this file help to transform data from our state into a shape
// that is compatible with the backend api
//
// Mainly, certain keys are whitelisted
// (to exclude others that are relevant to the frontend only)
// Some keys are added (e.g. the query type attribute)

import { DAYS_BEFORE, DAYS_OR_NO_EVENT_BEFORE } from '../common/constants/timebasedQueryOperatorTypes';

import { isEmpty } from '../common/helpers';

import '../standard-query-editor/types';

export var transformTablesToApi = function transformTablesToApi(tables) {
  return tables.filter(function (table) {
    return !table.exclude;
  }).map(function (table) {
    // Explicitly whitelist the tables that we allow to send to the API
    return {
      id: table.id,
      filters: table.filters ? table.filters.filter(function (filter) {
        return !isEmpty(filter.value);
      }) // Only send filters with a value
      .map(function (filter) {
        return {
          id: filter.id,
          type: filter.type,
          value: filter.value instanceof Array ? filter.value.map(function (v) {
            return v.value ? v.value : v;
          }) : filter.value
        };
      }) : []
    };
  });
};

export var transformElementGroupsToApi = function transformElementGroupsToApi(elementGroups) {
  return elementGroups.map(function (elements) {
    return {
      matchingType: elements.matchingType,
      elements: transformElementsToApi(elements.concepts)
    };
  });
};

export var transformElementsToApi = function transformElementsToApi(conceptGroup) {
  return conceptGroup.map(function (concept) {
    var tables = concept.tables ? transformTablesToApi(concept.tables) : [];

    return {
      ids: concept.ids,
      type: 'CONCEPT_LIST',
      label: concept.label,
      tables: tables
    };
  });
};

var transformStandardQueryToApi = function transformStandardQueryToApi(query, version) {
  return {
    version: version,
    type: 'CONCEPT_QUERY',
    groups: query.map(function (group) {
      return {
        exclude: group.exclude,
        dateRange: group.dateRange ? group.dateRange : undefined,
        elements: group.elements.map(function (element) {
          if (element.isPreviousQuery) {
            return {
              id: element.id,
              type: 'QUERY',
              excludeTimestamps: element.excludeTimestamps
            };
          } else {
            var tables = element.tables ? transformTablesToApi(element.tables) : [];

            return {
              ids: element.ids,
              type: 'CONCEPT_LIST',
              label: element.label,
              tables: tables,
              excludeTimestamps: element.excludeTimestamps
            };
          }
        })
      };
    })
  };
};

var transformResultToApi = function transformResultToApi(result) {
  return {
    id: result.id,
    timestamp: result.timestamp
  };
};

var getDayRange = function getDayRange(condition) {
  if (condition.operator === DAYS_BEFORE) return [{ minDays: condition.minDays }, { maxDays: condition.maxDays }];

  if (condition.operator === DAYS_OR_NO_EVENT_BEFORE) return [{ minDays: condition.minDaysOrNoEvent }, { maxDays: condition.maxDaysOrNoEvent }];

  return [{}, {}];
};

var transformTimebasedQueryToApi = function transformTimebasedQueryToApi(query, version) {
  return {
    version: version,
    type: 'TIME_QUERY',
    indexResult: query.indexResult,
    conditions: query.conditions.map(function (condition) {
      var _getDayRange = getDayRange(condition),
          _getDayRange2 = _slicedToArray(_getDayRange, 2),
          minDays = _getDayRange2[0],
          maxDays = _getDayRange2[1];

      return _extends({
        operator: condition.operator,
        result0: transformResultToApi(condition.result0),
        result1: transformResultToApi(condition.result1)
      }, minDays, maxDays);
    })
  };
};

// The query state already contains the query.
// But small additions are made (properties whitelisted), empty things filtered out
// to make it compatible with the backend API
export var transformQueryToApi = function transformQueryToApi(query, queryType, version) {
  return queryType === 'timebased' ? transformTimebasedQueryToApi(query, version) : transformStandardQueryToApi(query, version);
};
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(transformTablesToApi, 'transformTablesToApi', '/home/travis/build/bakdata/conquery/frontend/lib/js/api/apiHelper.js');
  reactHotLoader.register(transformElementGroupsToApi, 'transformElementGroupsToApi', '/home/travis/build/bakdata/conquery/frontend/lib/js/api/apiHelper.js');
  reactHotLoader.register(transformElementsToApi, 'transformElementsToApi', '/home/travis/build/bakdata/conquery/frontend/lib/js/api/apiHelper.js');
  reactHotLoader.register(transformStandardQueryToApi, 'transformStandardQueryToApi', '/home/travis/build/bakdata/conquery/frontend/lib/js/api/apiHelper.js');
  reactHotLoader.register(transformResultToApi, 'transformResultToApi', '/home/travis/build/bakdata/conquery/frontend/lib/js/api/apiHelper.js');
  reactHotLoader.register(getDayRange, 'getDayRange', '/home/travis/build/bakdata/conquery/frontend/lib/js/api/apiHelper.js');
  reactHotLoader.register(transformTimebasedQueryToApi, 'transformTimebasedQueryToApi', '/home/travis/build/bakdata/conquery/frontend/lib/js/api/apiHelper.js');
  reactHotLoader.register(transformQueryToApi, 'transformQueryToApi', '/home/travis/build/bakdata/conquery/frontend/lib/js/api/apiHelper.js');
  leaveModule(module);
})();

;