(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

import 'redux-thunk';

import '../dataset/reducer';
import api from '../api';
import { defaultSuccess, defaultError } from '../common/actions';

import { isEmpty } from '../common/helpers';

import { resetAllTrees } from './globalTreeStoreHelper';
import { LOAD_TREES_START, LOAD_TREES_SUCCESS, LOAD_TREES_ERROR, LOAD_TREE_START, LOAD_TREE_SUCCESS, LOAD_TREE_ERROR, CLEAR_TREES, SEARCH_TREES_START, SEARCH_TREES_END, SEARCH_TREES_ERROR, CHANGE_SEARCH_QUERY, CLEAR_SEARCH_QUERY } from './actionTypes';

export var clearTrees = function clearTrees() {
  return { type: CLEAR_TREES };
};

export var loadTreesStart = function loadTreesStart() {
  return { type: LOAD_TREES_START };
};
export var loadTreesError = function loadTreesError(err) {
  return defaultError(LOAD_TREES_ERROR, err);
};
export var loadTreesSuccess = function loadTreesSuccess(res) {
  return defaultSuccess(LOAD_TREES_SUCCESS, res);
};

export var loadTrees = function loadTrees(datasetId) {
  return function (dispatch) {
    // TODO: Careful, side effect, extract this soon
    resetAllTrees();

    dispatch(clearTrees());
    dispatch(loadTreesStart());

    return api.getConcepts(datasetId).then(function (r) {
      dispatch(loadTreesSuccess(r));

      // Assign default select filter values
      var _iteratorNormalCompletion = true;
      var _didIteratorError = false;
      var _iteratorError = undefined;

      try {
        for (var _iterator = Object.values(r.concepts)[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
          var concept = _step.value;
          var _iteratorNormalCompletion2 = true;
          var _didIteratorError2 = false;
          var _iteratorError2 = undefined;

          try {
            for (var _iterator2 = (concept.tables || [])[Symbol.iterator](), _step2; !(_iteratorNormalCompletion2 = (_step2 = _iterator2.next()).done); _iteratorNormalCompletion2 = true) {
              var table = _step2.value;
              var _iteratorNormalCompletion3 = true;
              var _didIteratorError3 = false;
              var _iteratorError3 = undefined;

              try {
                for (var _iterator3 = (table.filters || [])[Symbol.iterator](), _step3; !(_iteratorNormalCompletion3 = (_step3 = _iterator3.next()).done); _iteratorNormalCompletion3 = true) {
                  var filter = _step3.value;

                  if (filter.defaultValue) filter.value = filter.defaultValue;
                }
              } catch (err) {
                _didIteratorError3 = true;
                _iteratorError3 = err;
              } finally {
                try {
                  if (!_iteratorNormalCompletion3 && _iterator3.return) {
                    _iterator3.return();
                  }
                } finally {
                  if (_didIteratorError3) {
                    throw _iteratorError3;
                  }
                }
              }
            }
          } catch (err) {
            _didIteratorError2 = true;
            _iteratorError2 = err;
          } finally {
            try {
              if (!_iteratorNormalCompletion2 && _iterator2.return) {
                _iterator2.return();
              }
            } finally {
              if (_didIteratorError2) {
                throw _iteratorError2;
              }
            }
          }
        } // In the future: Data could be cached, version could be checked and
        // further data only loaded when necessary
      } catch (err) {
        _didIteratorError = true;
        _iteratorError = err;
      } finally {
        try {
          if (!_iteratorNormalCompletion && _iterator.return) {
            _iterator.return();
          }
        } finally {
          if (_didIteratorError) {
            throw _iteratorError;
          }
        }
      }

      if (r.version > -1) {
        Object.keys(r.concepts).forEach(function (conceptId) {
          if (r.concepts[conceptId].detailsAvailable) dispatch(loadTree(datasetId, conceptId));
        });

        return r.concepts;
      }
    }, function (e) {
      return dispatch(loadTreesError(e));
    });
  };
};

export var loadTreeStart = function loadTreeStart(treeId) {
  return { type: LOAD_TREE_START, payload: { treeId: treeId } };
};
export var loadTreeError = function loadTreeError(treeId, err) {
  return defaultError(LOAD_TREE_ERROR, err, { treeId: treeId });
};
export var loadTreeSuccess = function loadTreeSuccess(treeId, res) {
  return defaultSuccess(LOAD_TREE_SUCCESS, res, { treeId: treeId });
};

export var loadTree = function loadTree(datasetId, treeId) {
  return function (dispatch) {
    dispatch(loadTreeStart(treeId));

    return api.getConcept(datasetId, treeId).then(function (r) {
      return dispatch(loadTreeSuccess(treeId, r));
    }, function (e) {
      return dispatch(loadTreeError(treeId, e));
    });
  };
};

export var searchTreesStart = function searchTreesStart(query) {
  return { type: SEARCH_TREES_START, payload: { query: query } };
};
export var searchTreesEnd = function searchTreesEnd(query, searchResult) {
  return { type: SEARCH_TREES_END, payload: { query: query, searchResult: searchResult } };
};
export var searchTreesError = function searchTreesError(query, err) {
  return defaultError(SEARCH_TREES_ERROR, err, { query: query });
};

export var searchTrees = function searchTrees(datasetId, query, limit) {
  return function (dispatch) {
    dispatch(searchTreesStart(query));

    if (isEmpty(query)) return;

    return api.searchConcepts(datasetId, query, limit).then(function (r) {
      return dispatch(searchTreesEnd(query, r));
    }, function (e) {
      return dispatch(searchTreesError(query, e));
    });
  };
};

export var clearSearchQuery = function clearSearchQuery() {
  return { type: CLEAR_SEARCH_QUERY };
};
export var changeSearchQuery = function changeSearchQuery(query) {
  return { type: CHANGE_SEARCH_QUERY, payload: { query: query } };
};
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(clearTrees, 'clearTrees', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/actions.js');
  reactHotLoader.register(loadTreesStart, 'loadTreesStart', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/actions.js');
  reactHotLoader.register(loadTreesError, 'loadTreesError', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/actions.js');
  reactHotLoader.register(loadTreesSuccess, 'loadTreesSuccess', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/actions.js');
  reactHotLoader.register(loadTrees, 'loadTrees', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/actions.js');
  reactHotLoader.register(loadTreeStart, 'loadTreeStart', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/actions.js');
  reactHotLoader.register(loadTreeError, 'loadTreeError', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/actions.js');
  reactHotLoader.register(loadTreeSuccess, 'loadTreeSuccess', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/actions.js');
  reactHotLoader.register(loadTree, 'loadTree', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/actions.js');
  reactHotLoader.register(searchTreesStart, 'searchTreesStart', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/actions.js');
  reactHotLoader.register(searchTreesEnd, 'searchTreesEnd', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/actions.js');
  reactHotLoader.register(searchTreesError, 'searchTreesError', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/actions.js');
  reactHotLoader.register(searchTrees, 'searchTrees', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/actions.js');
  reactHotLoader.register(clearSearchQuery, 'clearSearchQuery', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/actions.js');
  reactHotLoader.register(changeSearchQuery, 'changeSearchQuery', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/actions.js');
  leaveModule(module);
})();

;