var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import { LOAD_TREES_START, LOAD_TREES_SUCCESS, LOAD_TREES_ERROR, LOAD_TREE_START, LOAD_TREE_SUCCESS, LOAD_TREE_ERROR, CLEAR_TREES, SEARCH_TREES_START, SEARCH_TREES_END, SEARCH_TREES_ERROR, CLEAR_SEARCH_QUERY, CHANGE_SEARCH_QUERY } from './actionTypes';

import { setTree } from './globalTreeStoreHelper';

var initialState = {
  loading: false,
  version: null,
  trees: {},
  search: {
    searching: false,
    loading: false,
    updateComponent: true,
    query: '',
    words: [],
    result: [],
    limit: 0,
    resultCount: 0,
    duration: 0
  }
};

var setSearchTreesEnd = function setSearchTreesEnd(state, action) {
  var _action$payload = action.payload,
      query = _action$payload.query,
      searchResult = _action$payload.searchResult;

  var searching = query && query.length > 0;
  var result = searchResult ? searchResult.result || [] : [];
  var limit = searchResult ? searchResult.limit : 50;
  var size = searchResult ? searchResult.size : 0;
  var matches = searchResult ? searchResult.matches : 0;

  return _extends({}, state, {
    search: {
      searching: searching,
      loading: false,
      updateComponent: true,
      query: query,
      words: query ? query.split(' ') : [],
      result: result,
      limit: matches <= limit ? matches : limit,
      resultCount: searching ? size : 0,
      duration: Date.now() - state.search.duration
    }
  });
};

var setSearchTreesStart = function setSearchTreesStart(state, action) {
  var query = action.payload.query;


  return _extends({}, state, {
    search: {
      searching: false,
      loading: query && query.length > 0,
      updateComponent: true,
      query: query,
      words: query ? query.split(' ') : [],
      result: [],
      resultCount: 0,
      limit: 0,
      duration: Date.now()
    }
  });
};

var updateTree = function updateTree(state, action, attributes) {
  return _extends({}, state, {
    trees: _extends({}, state.trees, _defineProperty({}, action.payload.treeId, _extends({}, state.trees[action.payload.treeId], attributes)))
  });
};

var setTreeLoading = function setTreeLoading(state, action) {
  return updateTree(state, action, { loading: true });
};

var setTreeSuccess = function setTreeSuccess(state, action) {
  // Side effect in a reducer.
  // Globally store the huge (1-5 MB) trees for read only
  // - keeps the redux store free from huge data
  var _action$payload2 = action.payload,
      treeId = _action$payload2.treeId,
      data = _action$payload2.data;

  var newState = updateTree(state, action, { loading: false });

  var rootConcept = newState.trees[treeId];

  setTree(rootConcept, treeId, data);

  return newState;
};

var setTreeError = function setTreeError(state, action) {
  return updateTree(state, action, { loading: false, error: action.payload.message });
};

var setLoadTreesSuccess = function setLoadTreesSuccess(state, action) {
  return _extends({}, state, {
    loading: false,
    version: action.payload.data.version,
    trees: action.payload.data.concepts
  });
};

var categoryTrees = function categoryTrees() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : initialState;
  var action = arguments[1];

  switch (action.type) {
    // All trees
    case LOAD_TREES_START:
      return _extends({}, state, { loading: true });
    case LOAD_TREES_SUCCESS:
      return setLoadTreesSuccess(state, action);
    case LOAD_TREES_ERROR:
      return _extends({}, state, { loading: false, error: action.payload.message });

    // Individual tree:
    case LOAD_TREE_START:
      return setTreeLoading(state, action);
    case LOAD_TREE_SUCCESS:
      return setTreeSuccess(state, action);
    case LOAD_TREE_ERROR:
      return setTreeError(state, action);
    case CLEAR_TREES:
      return initialState;
    case SEARCH_TREES_START:
      return setSearchTreesStart(state, action);
    case SEARCH_TREES_END:
      return setSearchTreesEnd(state, action);
    case SEARCH_TREES_ERROR:
      return _extends({}, state, {
        search: { loading: false },
        error: action.payload.message
      });
    case CLEAR_SEARCH_QUERY:
      return _extends({}, state, {
        search: { searching: false, query: '', updateComponent: true }
      });
    case CHANGE_SEARCH_QUERY:
      return _extends({}, state, {
        search: _extends({}, state.search, {
          query: action.payload.query,
          updateComponent: false
        })
      });
    default:
      return state;
  }
};

var _default = categoryTrees;
export default _default;
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(initialState, 'initialState', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/reducer.js');
  reactHotLoader.register(setSearchTreesEnd, 'setSearchTreesEnd', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/reducer.js');
  reactHotLoader.register(setSearchTreesStart, 'setSearchTreesStart', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/reducer.js');
  reactHotLoader.register(updateTree, 'updateTree', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/reducer.js');
  reactHotLoader.register(setTreeLoading, 'setTreeLoading', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/reducer.js');
  reactHotLoader.register(setTreeSuccess, 'setTreeSuccess', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/reducer.js');
  reactHotLoader.register(setTreeError, 'setTreeError', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/reducer.js');
  reactHotLoader.register(setLoadTreesSuccess, 'setLoadTreesSuccess', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/reducer.js');
  reactHotLoader.register(categoryTrees, 'categoryTrees', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/reducer.js');
  reactHotLoader.register(_default, 'default', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/reducer.js');
  leaveModule(module);
})();

;