(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

import { reset } from 'redux-form';

import { replace } from 'react-router-redux';

import { toDataset } from '../routes';

import api from '../api';

import { defaultError, defaultSuccess } from '../common/actions';

import { isEmpty } from '../common/helpers';

import { loadTrees } from '../category-trees/actions';

import { loadPreviousQueries } from '../previous-queries/list/actions';

import { loadQuery, clearQuery } from '../standard-query-editor/actions';

import '../standard-query-editor/types';

import { LOAD_DATASETS_START, LOAD_DATASETS_SUCCESS, LOAD_DATASETS_ERROR, SAVE_QUERY } from './actionTypes';

import './reducer';

export var loadDatasetsStart = function loadDatasetsStart() {
  return { type: LOAD_DATASETS_START };
};
export var loadDatasetsError = function loadDatasetsError(err) {
  return defaultError(LOAD_DATASETS_ERROR, err);
};
export var loadDatasetsSuccess = function loadDatasetsSuccess(res) {
  return defaultSuccess(LOAD_DATASETS_SUCCESS, res);
};

// Done at the very beginning on loading the site
export var loadDatasets = function loadDatasets(datasetIdFromUrl) {
  return function (dispatch) {
    dispatch(loadDatasetsStart());

    return api.getDatasets().then(function (datasets) {
      dispatch(loadDatasetsSuccess(datasets));

      var selectedDatasetId = datasetIdFromUrl;

      if (datasetIdFromUrl !== null)
        // Check if the user-provided id is valid
        if (!datasets.find(function (dataset) {
          return dataset.id === datasetIdFromUrl;
        })) selectedDatasetId = null;

      // Default to the first dataset from the list
      if (selectedDatasetId === null && !!datasets[0]) selectedDatasetId = datasets[0].id;

      if (datasetIdFromUrl !== selectedDatasetId) dispatch(selectDatasetInput(selectedDatasetId));

      if (selectedDatasetId) return dispatch(loadTrees(selectedDatasetId));
    }, function (e) {
      return dispatch(loadDatasetsError(e));
    });
  };
};

export var selectDatasetInput = function selectDatasetInput(datasetId) {
  if (datasetId && datasetId.length) return replace(toDataset(datasetId));

  return replace("/");
};

export var saveQuery = function saveQuery(query, previouslySelectedDatasetId) {
  return { type: SAVE_QUERY, payload: { query: query, previouslySelectedDatasetId: previouslySelectedDatasetId } };
};

export var selectDataset = function selectDataset(datasets, datasetId, previouslySelectedDatasetId, query) {
  return function (dispatch, state) {
    dispatch(saveQuery(query, previouslySelectedDatasetId));
    dispatch(selectDatasetInput(datasetId));

    // Load query if available, else clear
    if (isEmpty(datasetId)) {
      return dispatch(clearQuery());
    } else {
      var nextDataset = datasets.find(function (db) {
        return db.id === datasetId;
      });

      if (!nextDataset || !nextDataset.query) dispatch(clearQuery());else dispatch(loadQuery(nextDataset.query));

      dispatch(loadTrees(datasetId));
      // clearing Redux Form
      dispatch(reset(selectActiveForm(state)));

      return dispatch(loadPreviousQueries(datasetId));
    }
  };
};

var selectActiveForm = function selectActiveForm(getState) {
  var state = getState();
  return state.panes && state.panes.right && state.panes.right.tabs && state.panes.right.tabs.externalForms && state.panes.right.tabs.externalForms.externalForms && state.panes.right.tabs.externalForms.externalForms.activeForm;
};
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(loadDatasetsStart, 'loadDatasetsStart', '/home/travis/build/bakdata/conquery/frontend/lib/js/dataset/actions.js');
  reactHotLoader.register(loadDatasetsError, 'loadDatasetsError', '/home/travis/build/bakdata/conquery/frontend/lib/js/dataset/actions.js');
  reactHotLoader.register(loadDatasetsSuccess, 'loadDatasetsSuccess', '/home/travis/build/bakdata/conquery/frontend/lib/js/dataset/actions.js');
  reactHotLoader.register(loadDatasets, 'loadDatasets', '/home/travis/build/bakdata/conquery/frontend/lib/js/dataset/actions.js');
  reactHotLoader.register(selectDatasetInput, 'selectDatasetInput', '/home/travis/build/bakdata/conquery/frontend/lib/js/dataset/actions.js');
  reactHotLoader.register(saveQuery, 'saveQuery', '/home/travis/build/bakdata/conquery/frontend/lib/js/dataset/actions.js');
  reactHotLoader.register(selectDataset, 'selectDataset', '/home/travis/build/bakdata/conquery/frontend/lib/js/dataset/actions.js');
  reactHotLoader.register(selectActiveForm, 'selectActiveForm', '/home/travis/build/bakdata/conquery/frontend/lib/js/dataset/actions.js');
  leaveModule(module);
})();

;