(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

import { checkFileType, readFileAsText, cleanFileContent } from "../common/helpers";

import { defaultSuccess, defaultError } from "../common/actions";

import { uploadConceptListModalOpen } from "../upload-concept-list-modal/actions";
import { DROP_FILES_START, DROP_FILES_SUCCESS, DROP_FILES_ERROR } from "./actionTypes";


var initialGenericFileType = function initialGenericFileType(type) {
  return {
    parameters: type ? type.parameters : {},
    callback: uploadConceptListModalOpen
  };
};

export var loadFilesStart = function loadFilesStart() {
  return { type: DROP_FILES_START };
};
export var loadFilesSuccess = function loadFilesSuccess(res) {
  return defaultSuccess(DROP_FILES_SUCCESS, res);
};
export var loadFilesError = function loadFilesError(err) {
  return defaultError(DROP_FILES_ERROR, err);
};

export var dropFiles = function dropFiles(item, type) {
  return function (dispatch) {
    dispatch(loadFilesStart());

    type = !type || !type.callback ? initialGenericFileType(type) : type;

    // Ignore all dropped files except the first
    var file = item[0] || item.files[0];

    if (!checkFileType(file)) return dispatch(loadFilesError(new Error("Invalid concept list file")));

    return readFileAsText(file).then(function (r) {
      var values = cleanFileContent(r);
      type.parameters.values = values;
      type.parameters.fileName = file.name;

      if (values.length) return dispatch([loadFilesSuccess(r), type.callback(type)]);

      return dispatch(loadFilesError(new Error('An empty file was dropped')));
    }, function (e) {
      return dispatch(loadFilesError(e));
    });
  };
};

export var dropFilesAndIdx = function dropFilesAndIdx(item, andIdx) {
  return dropFiles(item, { parameters: { andIdx: andIdx }, callback: uploadConceptListModalOpen });
};

export var dropFilesDateRangeType = function dropFilesDateRangeType(item, dateRange) {
  return dropFiles(item, { parameters: { dateRange: dateRange }, callback: uploadConceptListModalOpen });
};
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(initialGenericFileType, "initialGenericFileType", "/home/travis/build/bakdata/conquery/frontend/lib/js/file-upload/actions.js");
  reactHotLoader.register(loadFilesStart, "loadFilesStart", "/home/travis/build/bakdata/conquery/frontend/lib/js/file-upload/actions.js");
  reactHotLoader.register(loadFilesSuccess, "loadFilesSuccess", "/home/travis/build/bakdata/conquery/frontend/lib/js/file-upload/actions.js");
  reactHotLoader.register(loadFilesError, "loadFilesError", "/home/travis/build/bakdata/conquery/frontend/lib/js/file-upload/actions.js");
  reactHotLoader.register(dropFiles, "dropFiles", "/home/travis/build/bakdata/conquery/frontend/lib/js/file-upload/actions.js");
  reactHotLoader.register(dropFilesAndIdx, "dropFilesAndIdx", "/home/travis/build/bakdata/conquery/frontend/lib/js/file-upload/actions.js");
  reactHotLoader.register(dropFilesDateRangeType, "dropFilesDateRangeType", "/home/travis/build/bakdata/conquery/frontend/lib/js/file-upload/actions.js");
  leaveModule(module);
})();

;