var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

import React from 'react';
import T from 'i18n-react';
import classnames from 'classnames';
import DatePicker from 'react-datepicker';
import moment from 'moment';
import 'redux-form';

import { dateTypes } from '../common/constants';
import { parseDatePattern, specificDatePattern } from '../common/helpers/dateHelper';
import { InfoTooltip } from '../tooltip';

import 'react-datepicker/dist/react-datepicker.css';

var DATE_FORMAT = dateTypes.DATE_FORMAT,
    localizedDateFormat = dateTypes.localizedDateFormat;


var formatDate = function formatDate(date) {
  return date ? date.format(DATE_FORMAT) : null;
};

var convertToDate = function convertToDate(date) {
  return date ? moment(date, DATE_FORMAT) : null;
};

var DateRangePicker = function DateRangePicker(props) {
  var minDate = convertToDate(props.input.value.minDate);
  var maxDate = convertToDate(props.input.value.maxDate);

  var onSetDate = function onSetDate(value) {
    return props.input.onChange(value);
  };

  var onSetMinDate = function onSetMinDate(date) {
    return props.input.onChange(_extends({}, props.input.value, {
      'minDate': date
    }));
  };

  var onSetMaxDate = function onSetMaxDate(date) {
    return props.input.onChange(_extends({}, props.input.value, {
      'maxDate': date
    }));
  };

  var onChangeRawMin = function onChangeRawMin(value) {
    var _specificDatePattern = specificDatePattern(value),
        minDate = _specificDatePattern.minDate,
        maxDate = _specificDatePattern.maxDate;

    if (!minDate) minDate = parseDatePattern(value);

    onSetMinDate(formatDate(minDate));

    if (maxDate && maxDate.isValid) onSetDate({ minDate: formatDate(minDate), maxDate: formatDate(maxDate) });
  };

  var onChangeRawMax = function onChangeRawMax(value) {
    var _specificDatePattern2 = specificDatePattern(value),
        maxDate = _specificDatePattern2.maxDate;

    if (!maxDate) maxDate = parseDatePattern(value);

    onSetMaxDate(formatDate(maxDate));
  };

  return React.createElement(
    'div',
    { className: props.className },
    React.createElement(
      'div',
      { className: '' },
      props.label && React.createElement(
        'span',
        { className: 'input input-label__inline' },
        props.label
      ),
      React.createElement(InfoTooltip, { className: 'inline', text: T.translate('tooltip.date.possiblePattern') })
    ),
    React.createElement(
      'div',
      { className: props.inputGroupClassName },
      React.createElement(
        'div',
        { className: props.inputGroupElementClassName },
        React.createElement(
          'label',
          {
            className: 'input-label',
            htmlFor: 'datepicker-min'
          },
          T.translate('externalForms.common.dateMinLabel')
        ),
        React.createElement(DatePicker, {
          id: 'datepicker-min',
          className: classnames({
            "query-group-modal__datepicker--has-value": !!minDate
          }),
          locale: 'de',
          dateFormat: localizedDateFormat(),
          selected: minDate,
          openToDate: minDate,
          maxDate: moment().add(2, "year"),
          placeholderText: T.translate('queryGroupModal.datePlaceholder'),
          onChange: function onChange(date) {
            return onSetMinDate(formatDate(date));
          },
          onChangeRaw: function onChangeRaw(event) {
            return onChangeRawMin(event.target.value);
          },
          ref: function ref(r) {
            if (r && minDate && minDate.isValid) {
              r.setOpen(false);
              r.setSelected(minDate);
            }
          },
          isClearable: true,
          showYearDropdown: true,
          scrollableYearDropdown: true,
          tabIndex: 1
        })
      ),
      React.createElement(
        'div',
        { className: props.inputGroupElementClassName },
        React.createElement(
          'label',
          {
            className: 'input-label',
            htmlFor: 'datepicker-max'
          },
          T.translate('externalForms.common.dateMaxLabel')
        ),
        React.createElement(DatePicker, {
          id: 'datepicker-max',
          className: classnames({
            "query-group-modal__datepicker--has-value": !!maxDate
          }),
          locale: 'de',
          dateFormat: localizedDateFormat(),
          selected: maxDate,
          openToDate: maxDate,
          maxDate: moment().add(2, "year"),
          placeholderText: T.translate('queryGroupModal.datePlaceholder'),
          onChange: function onChange(date) {
            return onSetMaxDate(formatDate(date));
          },
          onChangeRaw: function onChangeRaw(event) {
            return onChangeRawMax(event.target.value);
          },
          ref: function ref(r) {
            if (r && maxDate && maxDate.isValid) {
              r.setOpen(false);
              r.setSelected(maxDate);
            }
          },
          isClearable: true,
          showYearDropdown: true,
          scrollableYearDropdown: true,
          tabIndex: 2
        })
      )
    )
  );
};

var _default = DateRangePicker;
export default _default;
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(DATE_FORMAT, 'DATE_FORMAT', '/home/travis/build/bakdata/conquery/frontend/lib/js/form-components/DateRangePicker.js');
  reactHotLoader.register(localizedDateFormat, 'localizedDateFormat', '/home/travis/build/bakdata/conquery/frontend/lib/js/form-components/DateRangePicker.js');
  reactHotLoader.register(formatDate, 'formatDate', '/home/travis/build/bakdata/conquery/frontend/lib/js/form-components/DateRangePicker.js');
  reactHotLoader.register(convertToDate, 'convertToDate', '/home/travis/build/bakdata/conquery/frontend/lib/js/form-components/DateRangePicker.js');
  reactHotLoader.register(DateRangePicker, 'DateRangePicker', '/home/travis/build/bakdata/conquery/frontend/lib/js/form-components/DateRangePicker.js');
  reactHotLoader.register(_default, 'default', '/home/travis/build/bakdata/conquery/frontend/lib/js/form-components/DateRangePicker.js');
  leaveModule(module);
})();

;