(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import T from 'i18n-react';
import classnames from 'classnames';
import 'redux-form';

import { CurrencyType } from '../standard-query-editor/types';

import InputWithLabel from './InputWithLabel';
import ToggleButton from './ToggleButton';
import InputRangeHeader from './InputRangeHeader';

var InputRange = function InputRange(props) {
  var _props$input = props.input,
      value = _props$input.value,
      formattedValue = _props$input.formattedValue;
  // Make sure undefined / null is never set as a value, but an empty string instead

  var minValue = value && value.min || '';
  var maxValue = value && value.max || '';
  var exactValue = value && value.exact || '';

  var factor = props.currencyConfig && props.currencyConfig.factor || 1;
  var minFormattedValue = formattedValue && formattedValue.min || Math.round(minValue) / factor || null;
  var maxFormattedValue = formattedValue && formattedValue.max || Math.round(maxValue) / factor || null;
  var exactFormattedValue = formattedValue && formattedValue.exact || Math.round(exactValue) / factor || null;

  var isRangeMode = props.mode === 'range';
  var inputProps = {
    step: props.stepSize || null,
    min: props.limits && props.limits.min || null,
    max: props.limits && props.limits.max || null,
    currency: props.currencyConfig,
    pattern: props.pattern
  };

  var onChangeValue = function onChangeValue(type, newValue, newFormattedValue) {
    var value = props.input.value;

    var nextValue = newValue || null;
    var nextFormattedValue = newFormattedValue || null;

    if (type === 'exact') {
        // SET ENTIRE VALUE TO NULL IF POSSIBLE
        if (nextValue === null) props.input.onChange(null, null);else props.input.onChange({
          exact: nextValue
        }, {
          exact: nextFormattedValue
        });
    } else if (type === 'min' || type === 'max') {
      if (nextValue === null && (value && value.min == null && type === 'max' || value && value.max == null && type === 'min')) props.input.onChange(null, null);else props.input.onChange(_defineProperty({
        min: value ? value.min : null,
        max: value ? value.max : null
      }, type, nextValue), _defineProperty({
        min: props.input.formattedValue ? props.input.formattedValue.min : null,
        max: props.input.formattedValue ? props.input.formattedValue.max : null
      }, type, nextFormattedValue));
    } else props.input.onChange(null, null);
  };

  return React.createElement(
    'div',
    null,
    React.createElement(InputRangeHeader, {
      label: props.label,
      unit: props.unit,
      tooltip: props.tooltip,
      className: classnames('input-label', {
        'input-label--disabled': props.disabled
      })
    }),
    React.createElement(ToggleButton, {
      input: {
        value: props.mode || "range",
        onChange: function onChange(mode) {
          return props.onSwitchMode(mode);
        }
      },
      options: [{ value: 'range', label: T.translate('inputRange.range') }, { value: 'exact', label: T.translate('inputRange.exact') }]
    }),
    !isRangeMode && React.createElement(
      'div',
      { className: 'input-range__input-container' },
      React.createElement(InputWithLabel, {
        inputType: props.inputType,
        valueType: props.valueType,
        className: 'input-range__input-with-label',
        placeholder: '-',
        label: T.translate('inputRange.exactLabel'),
        tinyLabel: props.smallLabel || true,
        input: {
          value: exactValue,
          formattedValue: exactFormattedValue,
          onChange: function onChange(value, formattedValue) {
            return onChangeValue('exact', value, formattedValue);
          }
        },
        inputProps: inputProps
      })
    ),
    isRangeMode && React.createElement(
      'div',
      { className: 'input-range__input-container' },
      React.createElement(InputWithLabel, {
        inputType: props.inputType,
        valueType: props.valueType,
        className: 'input-range__input-with-label',
        placeholder: props.placeholder,
        label: T.translate('inputRange.minLabel'),
        tinyLabel: props.smallLabel || true,
        input: {
          value: minValue,
          formattedValue: minFormattedValue,
          onChange: function onChange(value, formattedValue) {
            return onChangeValue('min', value, formattedValue);
          }
        },
        inputProps: inputProps
      }),
      React.createElement(InputWithLabel, {
        inputType: props.inputType,
        valueType: props.valueType,
        className: 'input-range__input-with-label',
        placeholder: props.placeholder,
        label: T.translate('inputRange.maxLabel'),
        tinyLabel: props.smallLabel || true,
        input: {
          value: maxValue,
          formattedValue: maxFormattedValue,
          onChange: function onChange(value, formattedValue) {
            return onChangeValue('max', value, formattedValue);
          }
        },
        inputProps: inputProps
      })
    )
  );
};

var _default = InputRange;
export default _default;
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(InputRange, 'InputRange', '/home/travis/build/bakdata/conquery/frontend/lib/js/form-components/InputRange.js');
  reactHotLoader.register(_default, 'default', '/home/travis/build/bakdata/conquery/frontend/lib/js/form-components/InputRange.js');
  leaveModule(module);
})();

;