(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

import React from 'react';
import { Dot } from 'react-animated-dots';
import PropTypes from 'prop-types';
import T from 'i18n-react';
import { Creatable as Select } from 'react-select';
import { isEmpty, duration } from '../common/helpers';

var SearchBox = function SearchBox(props) {
  var searchResult = props.searchResult,
      searchConfig = props.searchConfig;


  return props.isMulti ? React.createElement(
    'div',
    { className: 'search-box' },
    React.createElement(Select, {
      name: 'input',
      value: props.search.map(function (t) {
        return { label: t, value: t };
      }),
      options: props.options ? props.options.map(function (t) {
        return { label: t, value: t };
      }) : [],
      onChange: function onChange(values) {
        return props.onSearch(values.map(function (v) {
          return v.value;
        }));
      },
      isMulti: true,
      placeholder: T.translate('reactSelect.searchPlaceholder'),
      noOptionsMessage: function noOptionsMessage() {
        return T.translate('reactSelect.noResults');
      }
    })
  ) : React.createElement(
    'div',
    { className: 'search-box input--full-width' },
    React.createElement('input', {
      className: 'search-box__input',
      placeholder: T.translate('search.placeholder'),
      value: searchResult.query || '',
      onChange: function onChange(e) {
        return isEmpty(e.target.value) ? props.onClearQuery() : props.onChange(e.target.value) || props.onSearch(e.target.value);
      },
      onKeyPress: function onKeyPress(e) {
        return e.key === 'Enter' ? props.onSearch(props.datasetId, e.target.value, searchConfig.limit) : null;
      }
    }),
    searchResult.loading ? React.createElement(
      'span',
      { className: 'dots' },
      React.createElement(
        Dot,
        null,
        '.'
      ),
      React.createElement(
        Dot,
        null,
        '.'
      ),
      React.createElement(
        Dot,
        null,
        '.'
      )
    ) : searchResult.searching && searchResult.resultCount >= 0 && React.createElement(
      'span',
      { className: 'input input-label--disabled input-label--tiny' },
      T.translate('search.resultLabel', {
        limit: searchResult.limit,
        resultCount: searchResult.resultCount,
        duration: duration(searchResult.duration, "milliseconds", T.translate("search.durationFormat"))
      })
    ),
    !isEmpty(searchResult.query) && React.createElement(
      'div',
      null,
      React.createElement('i', {
        className: 'search-box__search-icon fa fa-search fa-1',
        'aria-hidden': 'true',
        onClick: function onClick() {
          return props.onSearch(props.datasetId, searchResult.query, searchConfig.limit);
        }
      }),
      React.createElement(
        'span',
        {
          className: 'search-box__clear-zone',
          title: T.translate('common.clearValue'),
          'aria-label': T.translate('common.clearValue'),
          onClick: function onClick() {
            return props.onClearQuery() || props.onSearch('');
          }
        },
        '\xD7'
      )
    )
  );
};

SearchBox.propTypes = {
  search: PropTypes.arrayOf(PropTypes.string),
  onSearch: PropTypes.func.isRequired,
  onChange: PropTypes.func,
  onClearQuery: PropTypes.func,
  options: PropTypes.arrayOf(PropTypes.string),
  isMulti: PropTypes.bool,
  searchResult: PropTypes.object,
  datasetId: PropTypes.string,
  searchConfig: PropTypes.object
};

var _default = SearchBox;
export default _default;
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(SearchBox, 'SearchBox', '/home/travis/build/bakdata/conquery/frontend/lib/js/form-components/SearchBox.js');
  reactHotLoader.register(_default, 'default', '/home/travis/build/bakdata/conquery/frontend/lib/js/form-components/SearchBox.js');
  leaveModule(module);
})();

;