var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

import React from 'react';
import PropTypes from 'prop-types';
import T from 'i18n-react';
import { DragSource } from 'react-dnd';
import { connect } from 'react-redux';
import moment from 'moment';
import classnames from 'classnames';

import { ErrorMessage } from '../../error-message';
import { dndTypes } from '../../common/constants';
import { SelectableLabel } from '../../selectable-label';

import { CloseIconButton, DownloadButton } from '../../button';

import { EditableText, EditableTags } from '../../form-components';

import { deletePreviousQueryModalOpen } from '../delete-modal/actions';

import '../../standard-query-editor/types';

import { toggleSharePreviousQuery, renamePreviousQuery, retagPreviousQuery, toggleEditPreviousQueryLabel, toggleEditPreviousQueryTags } from './actions';

import PreviousQueryTags from './PreviousQueryTags';

var nodeSource = {
  beginDrag: function beginDrag(props) {
    // Return the data describing the dragged item
    return {
      id: props.query.id,
      label: props.query.label,
      isPreviousQuery: true
    };
  }
};

// These props get injected into the component
function collect(connect, monitor) {
  return {
    connectDragSource: connect.dragSource(),
    isDragging: monitor.isDragging()
  };
}

var PreviousQuery = function PreviousQuery(props) {
  var query = props.query,
      onRenamePreviousQuery = props.onRenamePreviousQuery,
      onToggleEditPreviousQueryTags = props.onToggleEditPreviousQueryTags,
      onToggleEditPreviousQueryLabel = props.onToggleEditPreviousQueryLabel,
      onRetagPreviousQuery = props.onRetagPreviousQuery,
      onToggleSharePreviousQuery = props.onToggleSharePreviousQuery;


  var peopleFound = query.numberOfResults + ' ' + T.translate('previousQueries.results');
  var executedAt = moment(query.createdAt).fromNow();
  var label = query.label || query.id.toString();
  var mayEditQuery = query.own || query.shared;
  var isNotEditing = !(query.editingLabel || query.editingTags);

  var content = React.createElement(
    'div',
    { className: classnames('previous-query', {
        'previous-query--own': !!query.own,
        'previous-query--shared': !!query.shared,
        'previous-query--system': !!query.system || !query.own && !query.shared
      }) },
    React.createElement(
      'p',
      { className: 'previous-query__top-infos' },
      React.createElement(
        'span',
        { className: 'previous-query__top-left' },
        query.resultUrl ? React.createElement(DownloadButton, {
          className: 'btn--icon',
          url: query.resultUrl,
          label: peopleFound
        }) : peopleFound,
        query.own && (query.shared ? React.createElement(
          'span',
          {
            onClick: function onClick() {
              return onToggleSharePreviousQuery(!query.shared);
            },
            className: 'previous-query__shared-indicator' },
          T.translate('previousQuery.shared')
        ) : React.createElement(
          'span',
          {
            onClick: function onClick() {
              return onToggleSharePreviousQuery(!query.shared);
            },
            className: 'previous-query__btn btn--icon'
          },
          React.createElement('i', { className: 'fa fa-upload' }),
          ' ',
          T.translate('previousQuery.share')
        )),
        mayEditQuery && !query.editingTags && React.createElement(
          'span',
          {
            onClick: onToggleEditPreviousQueryTags,
            className: 'previous-query__btn previous-query__hover-btn btn--icon'
          },
          React.createElement('i', { className: 'fa fa-plus' }),
          ' ',
          T.translate('previousQuery.addTag')
        )
      ),
      React.createElement(
        'span',
        { className: 'previous-query__top-right' },
        executedAt,
        query.loading ? React.createElement('span', { className: 'btn--icon--padded fa fa-spinner' }) : query.own && React.createElement(CloseIconButton, { onClick: props.onDeletePreviousQuery })
      )
    ),
    React.createElement(
      'div',
      { className: 'previous-query__middle-row' },
      mayEditQuery ? React.createElement(EditableText, {
        className: 'previous-query__label',
        loading: !!query.loading,
        text: label,
        selectTextOnMount: true,
        editing: !!query.editingLabel,
        onSubmit: onRenamePreviousQuery,
        onToggleEdit: onToggleEditPreviousQueryLabel
      }) : React.createElement(SelectableLabel, { className: 'previous-query__label', label: label }),
      React.createElement(
        'span',
        { className: 'previous-query__top-infos' },
        query.ownerName
      )
    ),
    mayEditQuery ? React.createElement(EditableTags, {
      className: 'previous-query__tags',
      tags: query.tags,
      editing: !!query.editingTags,
      loading: !!query.loading,
      onSubmit: onRetagPreviousQuery,
      onToggleEdit: onToggleEditPreviousQueryTags,
      tagComponent: React.createElement(PreviousQueryTags, {
        className: 'editable-tags__tags',
        tags: query.tags
      }),
      availableTags: props.availableTags
    }) : React.createElement(PreviousQueryTags, {
      className: 'previous-query__tags editable-tags__tags',
      tags: query.tags
    }),
    !!query.error && React.createElement(ErrorMessage, {
      className: 'previous-query__error',
      message: query.error
    })
  );
  return isNotEditing ? props.connectDragSource(content) : content;
};

PreviousQuery.propTypes = {
  query: PropTypes.shape({
    id: PropTypes.oneOfType([PropTypes.number, PropTypes.string]).isRequired,
    label: PropTypes.string,
    loading: PropTypes.bool,
    numberOfResults: PropTypes.number.isRequired,
    createdAt: PropTypes.string.isRequired,
    tags: PropTypes.arrayOf(PropTypes.string),
    own: PropTypes.bool,
    shared: PropTypes.bool
  }).isRequired,
  onRenamePreviousQuery: PropTypes.func.isRequired,
  onToggleEditPreviousQueryLabel: PropTypes.func.isRequired,
  onToggleEditPreviousQueryTags: PropTypes.func.isRequired,
  onToggleSharePreviousQuery: PropTypes.func.isRequired,
  onRetagPreviousQuery: PropTypes.func.isRequired,
  onDeletePreviousQuery: PropTypes.func.isRequired,
  connectDragSource: PropTypes.func.isRequired,
  availableTags: PropTypes.arrayOf(PropTypes.string)
};

var mapStateToProps = function mapStateToProps(state) {
  return {
    availableTags: state.previousQueries.tags
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {
    onToggleSharePreviousQuery: function onToggleSharePreviousQuery(datasetId, queryId, shared) {
      return dispatch(toggleSharePreviousQuery(datasetId, queryId, shared));
    },

    onRenamePreviousQuery: function onRenamePreviousQuery(datasetId, queryId, label) {
      return dispatch(renamePreviousQuery(datasetId, queryId, label));
    },

    onRetagPreviousQuery: function onRetagPreviousQuery(datasetId, queryId, tags) {
      return dispatch(retagPreviousQuery(datasetId, queryId, tags));
    },

    onDeletePreviousQuery: function onDeletePreviousQuery(queryId) {
      return dispatch(deletePreviousQueryModalOpen(queryId));
    },

    onToggleEditPreviousQueryLabel: function onToggleEditPreviousQueryLabel(queryId) {
      return dispatch(toggleEditPreviousQueryLabel(queryId));
    },

    onToggleEditPreviousQueryTags: function onToggleEditPreviousQueryTags(queryId) {
      return dispatch(toggleEditPreviousQueryTags(queryId));
    }
  };
};

var mapProps = function mapProps(stateProps, dispatchProps, ownProps) {
  return _extends({}, stateProps, dispatchProps, ownProps, {
    onToggleSharePreviousQuery: function onToggleSharePreviousQuery(shared) {
      return dispatchProps.onToggleSharePreviousQuery(ownProps.datasetId, ownProps.query.id, shared);
    },
    onRenamePreviousQuery: function onRenamePreviousQuery(label) {
      return dispatchProps.onRenamePreviousQuery(ownProps.datasetId, ownProps.query.id, label);
    },
    onRetagPreviousQuery: function onRetagPreviousQuery(tags) {
      return dispatchProps.onRetagPreviousQuery(ownProps.datasetId, ownProps.query.id, tags);
    },
    onDeletePreviousQuery: function onDeletePreviousQuery() {
      return dispatchProps.onDeletePreviousQuery(ownProps.query.id);
    },
    onToggleEditPreviousQueryLabel: function onToggleEditPreviousQueryLabel() {
      return dispatchProps.onToggleEditPreviousQueryLabel(ownProps.query.id);
    },
    onToggleEditPreviousQueryTags: function onToggleEditPreviousQueryTags() {
      return dispatchProps.onToggleEditPreviousQueryTags(ownProps.query.id);
    }
  });
};

var _default = DragSource(dndTypes.PREVIOUS_QUERY, nodeSource, collect)(connect(mapStateToProps, mapDispatchToProps, mapProps)(PreviousQuery));

export default _default;
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(nodeSource, 'nodeSource', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/PreviousQuery.js');
  reactHotLoader.register(collect, 'collect', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/PreviousQuery.js');
  reactHotLoader.register(PreviousQuery, 'PreviousQuery', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/PreviousQuery.js');
  reactHotLoader.register(mapStateToProps, 'mapStateToProps', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/PreviousQuery.js');
  reactHotLoader.register(mapDispatchToProps, 'mapDispatchToProps', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/PreviousQuery.js');
  reactHotLoader.register(mapProps, 'mapProps', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/PreviousQuery.js');
  reactHotLoader.register(_default, 'default', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/PreviousQuery.js');
  leaveModule(module);
})();

;