var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

import React from 'react';
import PropTypes from 'prop-types';
import classnames from 'classnames';
import T from 'i18n-react';
import { connect } from 'react-redux';
import DatePicker from 'react-datepicker';
import ie from 'ie-version';
import moment from 'moment';

import { dateTypes } from '../common/constants';
import { Modal } from '../modal';
import { InfoTooltip } from '../tooltip';
import { specificDatePattern, parseDatePattern } from '../common/helpers/dateHelper';

import { queryGroupModalClearNode, queryGroupModalSetMinDate, queryGroupModalSetMaxDate, queryGroupModalResetAllDates, queryGroupModalSetTouched } from './actions';

var DATE_FORMAT = dateTypes.DATE_FORMAT,
    localizedDateFormat = dateTypes.localizedDateFormat;


var formatDate = function formatDate(date) {
  return date ? date.format(DATE_FORMAT) : null;
};

var getGroupDate = function getGroupDate(dateRange, minOrMax) {
  return dateRange && dateRange[minOrMax] ? moment(dateRange[minOrMax], DATE_FORMAT) : null;
};

var getTouched = function getTouched(touched, minOrMax) {
  return touched && touched[minOrMax] ? touched[minOrMax] : false;
};

var QueryGroupModal = function QueryGroupModal(props) {
  if (!props.group) return null;

  var min = 'min';
  var max = 'max';

  var minDate = getGroupDate(props.group.dateRange, min);
  var maxDate = getGroupDate(props.group.dateRange, max);
  var hasActiveDate = !!(minDate || maxDate);

  var minTouched = getTouched(props.group.touched, min);
  var maxTouched = getTouched(props.group.touched, max);

  var onSetMinDate = props.onSetMinDate,
      onSetMaxDate = props.onSetMaxDate,
      onSetTouched = props.onSetTouched;


  var onChangeRawMin = function onChangeRawMin(value) {
    var _specificDatePattern = specificDatePattern(value),
        minDate = _specificDatePattern.minDate,
        maxDate = _specificDatePattern.maxDate;

    if (!minDate) minDate = parseDatePattern(value);

    onSetMinDate(formatDate(minDate));

    if (maxDate && maxDate.isValid) onSetMaxDate(formatDate(maxDate));
  };

  var onChangeRawMax = function onChangeRawMax(value) {
    var _specificDatePattern2 = specificDatePattern(value),
        maxDate = _specificDatePattern2.maxDate;

    if (!maxDate) maxDate = parseDatePattern(value);

    onSetMaxDate(formatDate(maxDate));
  };

  return React.createElement(
    Modal,
    { closeModal: props.onCloseModal, doneButton: true, tabIndex: 3 },
    React.createElement(
      'div',
      { className: 'query-group-modal' },
      React.createElement(
        'h3',
        { className: 'query-group-modal__headline' },
        props.group.elements.reduce(function (parts, concept, i, elements) {
          return [].concat(_toConsumableArray(parts), [React.createElement(
            'span',
            {
              key: i,
              className: 'query-group-modal__headline-part'
            },
            concept.label || concept.id
          ), i !== elements.length - 1 ? React.createElement(
            'span',
            { key: i + '-comma' },
            ', '
          ) : '']);
        }, [React.createElement(
          'span',
          { key: -1, className: 'query-group-modal__headline-part' },
          T.translate('queryGroupModal.headlineStart')
        )])
      ),
      React.createElement(
        'p',
        { className: 'query-group-modal__explanation' },
        T.translate('queryGroupModal.explanation'),
        React.createElement(InfoTooltip, { text: T.translate('tooltip.date.possiblePattern') }),
        hasActiveDate && React.createElement(
          'span',
          {
            className: 'query-group-modal__reset-all',
            onClick: props.onResetAllDates
          },
          React.createElement('i', { className: 'fa fa-undo' }),
          ' ',
          T.translate('queryNodeEditor.resetAll')
        )
      ),
      React.createElement(
        'div',
        { className: 'query-group-modal__dates ' + (ie.version && ie.version === 11 ? ' ie11' : '') },
        React.createElement(
          'div',
          { className: 'query-group-modal__input-group' },
          React.createElement(
            'label',
            { className: 'input-label', htmlFor: 'datepicker-min' },
            T.translate('queryGroupModal.dateMinLabel')
          ),
          React.createElement(DatePicker, {
            id: 'datepicker-min',
            className: classnames('query-group-modal__datepicker', {
              'query-group-modal__datepicker--has-value': !!minDate,
              'query-group-modal__datepicker--invalid': !minDate && minTouched && hasActiveDate
            }),
            locale: 'de',
            dateFormat: localizedDateFormat(),
            selected: minDate,
            openToDate: minDate,
            maxDate: moment().add(2, "year"),
            placeholderText: T.translate('queryGroupModal.datePlaceholder'),
            onChange: function onChange(date) {
              return onSetMinDate(formatDate(date));
            },
            onChangeRaw: function onChangeRaw(event) {
              return onChangeRawMin(event.target.value);
            },
            onBlur: function onBlur(event) {
              return onSetTouched(min);
            },
            ref: function ref(r) {
              if (r && minDate && minDate.isValid) {
                r.setOpen(false);
                r.setSelected(minDate);
              }
            },
            isClearable: true,
            showYearDropdown: true,
            scrollableYearDropdown: true,
            tabIndex: 1
          })
        ),
        React.createElement(
          'div',
          { className: 'query-group-modal__input-group' },
          React.createElement(
            'label',
            { className: 'input-label', htmlFor: 'datepicker-max' },
            T.translate('queryGroupModal.dateMaxLabel')
          ),
          React.createElement(DatePicker, {
            id: 'datepicker-max',
            className: classnames('query-group-modal__datepicker', {
              'query-group-modal__datepicker--has-value': !!maxDate,
              'query-group-modal__datepicker--invalid': !maxDate && maxTouched && hasActiveDate
            }),
            locale: 'de',
            dateFormat: localizedDateFormat(),
            selected: maxDate,
            openToDate: maxDate,
            maxDate: moment().add(2, "year"),
            placeholderText: T.translate('queryGroupModal.datePlaceholder'),
            onChange: function onChange(date) {
              return onSetMaxDate(formatDate(date));
            },
            onChangeRaw: function onChangeRaw(event) {
              return onChangeRawMax(event.target.value);
            },
            onBlur: function onBlur(event) {
              return onSetTouched(max);
            },
            ref: function ref(r) {
              if (r && maxDate && maxDate.isValid) {
                r.setOpen(false);
                r.setSelected(maxDate);
              }
            },
            isClearable: true,
            showYearDropdown: true,
            scrollableYearDropdown: true,
            tabIndex: 2
          })
        )
      )
    )
  );
};

QueryGroupModal.propTypes = {
  group: PropTypes.object,
  andIdx: PropTypes.number,
  onCloseModal: PropTypes.func.isRequired,
  onSetMinDate: PropTypes.func.isRequired,
  onSetMaxDate: PropTypes.func.isRequired,
  onResetAllDates: PropTypes.func.isRequired,
  onSetTouched: PropTypes.func
};

function findGroup(query, andIdx) {
  if (!query[andIdx]) return null;

  return query[andIdx];
}

var mapStateToProps = function mapStateToProps(state) {
  return {
    group: findGroup(state.panes.right.tabs.queryEditor.query, state.queryGroupModal.andIdx),
    andIdx: state.queryGroupModal.andIdx
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {
    onCloseModal: function onCloseModal() {
      return dispatch(queryGroupModalClearNode());
    },
    onSetMinDate: function onSetMinDate(andIdx, date) {
      return dispatch(queryGroupModalSetMinDate(andIdx, date));
    },
    onSetMaxDate: function onSetMaxDate(andIdx, date) {
      return dispatch(queryGroupModalSetMaxDate(andIdx, date));
    },
    onResetAllDates: function onResetAllDates(andIdx) {
      return dispatch(queryGroupModalResetAllDates(andIdx));
    },
    onSetTouched: function onSetTouched(andIdx, field, value) {
      return dispatch(queryGroupModalSetTouched(andIdx, field));
    }
  };
};

// Used to enhance the dispatchProps with the andIdx
var mergeProps = function mergeProps(stateProps, dispatchProps, ownProps) {
  return _extends({}, ownProps, stateProps, dispatchProps, {
    onSetMinDate: function onSetMinDate(date) {
      return dispatchProps.onSetMinDate(stateProps.andIdx, date);
    },
    onSetMaxDate: function onSetMaxDate(date) {
      return dispatchProps.onSetMaxDate(stateProps.andIdx, date);
    },
    onResetAllDates: function onResetAllDates() {
      return dispatchProps.onResetAllDates(stateProps.andIdx);
    },
    onSetTouched: function onSetTouched(field) {
      return dispatchProps.onSetTouched(stateProps.andIdx, field);
    }
  });
};

var _default = connect(mapStateToProps, mapDispatchToProps, mergeProps)(QueryGroupModal);

export default _default;
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(DATE_FORMAT, 'DATE_FORMAT', '/home/travis/build/bakdata/conquery/frontend/lib/js/query-group-modal/QueryGroupModal.js');
  reactHotLoader.register(localizedDateFormat, 'localizedDateFormat', '/home/travis/build/bakdata/conquery/frontend/lib/js/query-group-modal/QueryGroupModal.js');
  reactHotLoader.register(formatDate, 'formatDate', '/home/travis/build/bakdata/conquery/frontend/lib/js/query-group-modal/QueryGroupModal.js');
  reactHotLoader.register(getGroupDate, 'getGroupDate', '/home/travis/build/bakdata/conquery/frontend/lib/js/query-group-modal/QueryGroupModal.js');
  reactHotLoader.register(getTouched, 'getTouched', '/home/travis/build/bakdata/conquery/frontend/lib/js/query-group-modal/QueryGroupModal.js');
  reactHotLoader.register(QueryGroupModal, 'QueryGroupModal', '/home/travis/build/bakdata/conquery/frontend/lib/js/query-group-modal/QueryGroupModal.js');
  reactHotLoader.register(findGroup, 'findGroup', '/home/travis/build/bakdata/conquery/frontend/lib/js/query-group-modal/QueryGroupModal.js');
  reactHotLoader.register(mapStateToProps, 'mapStateToProps', '/home/travis/build/bakdata/conquery/frontend/lib/js/query-group-modal/QueryGroupModal.js');
  reactHotLoader.register(mapDispatchToProps, 'mapDispatchToProps', '/home/travis/build/bakdata/conquery/frontend/lib/js/query-group-modal/QueryGroupModal.js');
  reactHotLoader.register(mergeProps, 'mergeProps', '/home/travis/build/bakdata/conquery/frontend/lib/js/query-group-modal/QueryGroupModal.js');
  reactHotLoader.register(_default, 'default', '/home/travis/build/bakdata/conquery/frontend/lib/js/query-group-modal/QueryGroupModal.js');
  leaveModule(module);
})();

;