(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

import React from 'react';
import T from 'i18n-react';
import classnames from 'classnames';

import { tableHasActiveFilters } from '../model/table';
import { nodeHasActiveFilters } from '../model/node';

export var MenuColumn = function MenuColumn(props) {
  var node = props.node,
      editorState = props.editorState;


  var onlyOneTableIncluded = !node.isPreviousQuery ? node.tables.filter(function (table) {
    return !table.exclude;
  }).length === 1 : undefined;
  var allowToggleTables = !node.isPreviousQuery ? node.tables.map(function (table) {
    return table.exclude || !onlyOneTableIncluded;
  }) : undefined;

  return React.createElement(
    'div',
    { className: 'query-node-editor__fixed_column query-node-editor__column' },
    React.createElement(
      'div',
      { className: 'query-node-editor__category_header' },
      T.translate('queryNodeEditor.queryNode')
    ),
    React.createElement(
      'button',
      {
        className: classnames('query-node-editor__category_element', 'btn', 'btn--header-transparent', { 'query-node-editor__category_element_active': editorState.detailsViewActive }),
        onClick: function onClick(e) {
          e.preventDefault();editorState.onSelectDetailsView();
        }
      },
      T.translate('queryNodeEditor.properties')
    ),
    !node.isPreviousQuery && props.showTables && React.createElement(
      'div',
      null,
      React.createElement(
        'div',
        { className: 'query-node-editor__category_header' },
        T.translate('queryNodeEditor.conceptNodeTables')
      ),
      node.tables.map(function (table, tableIdx) {
        return React.createElement(
          'div',
          {
            key: tableIdx,
            className: classnames('query-node-editor__category_element', 'btn', 'btn--header-transparent', {
              'query-node-editor__category_element_active': editorState.selectedInputTableIdx === tableIdx && !editorState.detailsViewActive
            }),
            onClick: function onClick() {
              editorState.onSelectInputTableView(tableIdx);
            }
          },
          React.createElement('i', {
            className: classnames('fa', {
              'fa-square-o': !!table.exclude,
              'fa-check-square-o': !table.exclude,
              'query-node-editor__exclude_icon': allowToggleTables[tableIdx],
              'query-node-editor__exclude_icon_disabled': !allowToggleTables[tableIdx]
            }),
            onClick: function onClick(event) {
              event.stopPropagation();
              if (allowToggleTables[tableIdx]) props.onToggleTable(tableIdx, !table.exclude);
            }
          }),
          React.createElement(
            'span',
            null,
            table.label
          ),
          tableHasActiveFilters(table) && React.createElement('i', { className: 'fa fa-filter query-node-editor__filter_icon' })
        );
      }),
      nodeHasActiveFilters(node) && React.createElement(
        'div',
        { className: 'query-node-editor__category_action' },
        React.createElement(
          'span',
          {
            className: 'query-node-editor__reset-all',
            onClick: function onClick() {
              return props.onResetAllFilters();
            }
          },
          React.createElement('i', { className: 'fa fa-undo' }),
          ' ',
          T.translate('queryNodeEditor.resetAll')
        )
      )
    )
  );
};
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(MenuColumn, 'MenuColumn', '/home/travis/build/bakdata/conquery/frontend/lib/js/query-node-editor/MenuColumn.js');
  leaveModule(module);
})();

;