(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

import React from 'react';

import { includes } from '../common/helpers';

import { InputSelect, InputMultiSelect, InputRange, AsyncInputMultiSelect, InputWithLabel, SUPPORTED_FILTERS, SELECT, MULTI_SELECT, INTEGER_RANGE, REAL_RANGE, MONEY_RANGE, STRING, BIG_MULTI_SELECT } from '../form-components';

import { CurrencyType } from '../standard-query-editor/types';

var ParameterTableFilters = function ParameterTableFilters(props) {
  return props.filters ? React.createElement(
    'div',
    null,
    props.filters.filter(function (f) {
      return includes(Object.keys(SUPPORTED_FILTERS), f.type);
    }).map(function (filter, filterIdx) {
      switch (filter.type) {
        case SELECT:
          return React.createElement(InputSelect, {
            input: {
              clearable: filter.value !== filter.defaultValue,
              defaultValue: filter.defaultValue,
              value: filter.value,
              onChange: function onChange(value) {
                return props.onSetFilterValue(filterIdx, value);
              }
            },
            label: filter.label,
            options: filter.options,
            disabled: props.excludeTable
          });
        case MULTI_SELECT:
          return React.createElement(InputMultiSelect, {
            input: {
              onChange: function onChange(value) {
                return props.onSetFilterValue(filterIdx, value);
              },
              defaultValue: filter.defaultValue,
              value: filter.value
            },
            label: filter.label,
            options: filter.options,
            disabled: props.excludeTable,
            onDropFiles: function onDropFiles(files) {
              return props.onDropFiles(filterIdx, filter.id, files);
            },
            allowDropFile: !!filter.allowDropFile
          });
        case BIG_MULTI_SELECT:
          return React.createElement(AsyncInputMultiSelect, {
            input: {
              value: filter.value,
              defaultValue: filter.defaultValue,
              onChange: function onChange(value) {
                return props.onSetFilterValue(filterIdx, value);
              }
            },
            label: filter.label,
            options: filter.options || props.suggestions && props.suggestions[filterIdx] && props.suggestions[filterIdx].options,
            isLoading: filter.isLoading || props.suggestions && props.suggestions[filterIdx] && props.suggestions[filterIdx].isLoading,
            startLoadingThreshold: filter.threshold || 1,
            onLoad: function onLoad(prefix) {
              return props.onLoadFilterSuggestions(filterIdx, filter.id, prefix);
            },
            onDropFiles: function onDropFiles(files) {
              return props.onDropFiles(filterIdx, filter.id, files);
            },
            allowDropFile: !!filter.allowDropFile,
            disabled: !!props.excludeTable
          });
        case INTEGER_RANGE:
          return React.createElement(InputRange, {
            inputType: 'number',
            input: {
              value: filter.value,
              defaultValue: filter.defaultValue,
              onChange: function onChange(value) {
                return props.onSetFilterValue(filterIdx, value);
              }
            },
            limits: { min: filter.min, max: filter.max },
            unit: filter.unit,
            label: filter.label,
            mode: filter.mode || 'range',
            disabled: !!props.excludeTable,
            onSwitchMode: function onSwitchMode(mode) {
              return props.onSwitchFilterMode(filterIdx, mode);
            },
            placeholder: '-',
            pattern: filter.pattern
          });
        case REAL_RANGE:
          return React.createElement(InputRange, {
            inputType: 'number',
            input: {
              value: filter.value,
              defaultValue: filter.defaultValue,
              onChange: function onChange(value) {
                return props.onSetFilterValue(filterIdx, value);
              }
            },
            limits: { min: filter.min, max: filter.max },
            unit: filter.unit,
            label: filter.label,
            mode: filter.mode || 'range',
            stepSize: filter.precision || 0.1,
            disabled: !!props.excludeTable,
            onSwitchMode: function onSwitchMode(mode) {
              return props.onSwitchFilterMode(filterIdx, mode);
            },
            placeholder: '-',
            pattern: filter.pattern
          });
        case MONEY_RANGE:
          return React.createElement(InputRange, {
            inputType: 'text',
            valueType: MONEY_RANGE,
            input: {
              value: filter.value || "",
              formattedValue: filter.formattedValue,
              onChange: function onChange(value, formattedValue) {
                return props.onSetFilterValue(filterIdx, value, formattedValue);
              }
            },
            unit: filter.unit,
            label: filter.label,
            mode: filter.mode || 'range',
            disabled: !!props.excludeTable,
            onSwitchMode: function onSwitchMode(mode) {
              return props.onSwitchFilterMode(filterIdx, mode);
            },
            placeholder: '-',
            currencyConfig: props.currencyConfig
          });
        case STRING:
          return React.createElement(InputWithLabel, {
            inputType: 'text',
            input: {
              value: filter.value || "",
              defaultValue: filter.defaultValue,
              onChange: function onChange(value) {
                return props.onSetFilterValue(filterIdx, value);
              }
            },
            placeholder: '-',
            label: filter.label
          });
        default:
          // In the future, there might be other filter types supported
          return null;
      }
    }).filter(function (input) {
      return !!input;
    }).map(function (input, filterIdx) {
      return React.createElement(
        'div',
        {
          key: filterIdx,
          className: 'query-node-editor__row',
          onFocusCapture: function onFocusCapture() {
            return props.onShowDescription(filterIdx);
          }
        },
        input
      );
    })
  ) : null;
};

var _default = ParameterTableFilters;
export default _default;
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(ParameterTableFilters, 'ParameterTableFilters', '/home/travis/build/bakdata/conquery/frontend/lib/js/query-node-editor/ParameterTableFilters.js');
  reactHotLoader.register(_default, 'default', '/home/travis/build/bakdata/conquery/frontend/lib/js/query-node-editor/ParameterTableFilters.js');
  leaveModule(module);
})();

;