(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import { replace } from 'react-router-redux';

import api from '../api';
import { toQuery } from '../routes';

import { defaultSuccess, defaultError } from '../common/actions';

import { capitalize, toUpperCaseUnderscore } from '../common/helpers';

import { loadPreviousQueries } from '../previous-queries/list/actions';

import * as actionTypes from './actionTypes';
import { QUERY_AGAIN_TIMEOUT } from './constants';

export default function createQueryRunnerActions(type) {
  var _ref;

  var isExternalForm = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;

  var uppercaseType = toUpperCaseUnderscore(type);
  var capitalizedType = capitalize(type);

  var START_QUERY_START = actionTypes['START_' + uppercaseType + '_QUERY_START'];
  var START_QUERY_SUCCESS = actionTypes['START_' + uppercaseType + '_QUERY_SUCCESS'];
  var START_QUERY_ERROR = actionTypes['START_' + uppercaseType + '_QUERY_ERROR'];
  var STOP_QUERY_START = actionTypes['STOP_' + uppercaseType + '_QUERY_START'];
  var STOP_QUERY_SUCCESS = actionTypes['STOP_' + uppercaseType + '_QUERY_SUCCESS'];
  var STOP_QUERY_ERROR = actionTypes['STOP_' + uppercaseType + '_QUERY_ERROR'];
  var QUERY_RESULT_START = actionTypes['QUERY_' + uppercaseType + '_RESULT_START'];
  var QUERY_RESULT_STOP = actionTypes['QUERY_' + uppercaseType + '_RESULT_STOP'];
  var QUERY_RESULT_SUCCESS = actionTypes['QUERY_' + uppercaseType + '_RESULT_SUCCESS'];
  var QUERY_RESULT_ERROR = actionTypes['QUERY_' + uppercaseType + '_RESULT_ERROR'];

  var startQueryStart = function startQueryStart() {
    return { type: START_QUERY_START };
  };
  var startQueryError = function startQueryError(err) {
    return defaultError(START_QUERY_ERROR, err);
  };
  var startQuerySuccess = function startQuerySuccess(res) {
    return defaultSuccess(START_QUERY_SUCCESS, res);
  };
  var startQuery = function startQuery(datasetId, query, version) {
    var formQueryTransformation = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : function (form) {
      return form;
    };

    return function (dispatch) {
      dispatch(startQueryStart());

      var apiMethod = isExternalForm ? function () {
        for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
          args[_key] = arguments[_key];
        }

        return api.postFormQueries.apply(api, args.concat([formQueryTransformation]));
      } : api.postQueries;

      return apiMethod(datasetId, query, type, version).then(function (r) {
        dispatch(startQuerySuccess(r));

        var queryId = r.id;

        dispatch(replace(toQuery(datasetId, queryId)));

        return dispatch(queryResult(datasetId, queryId));
      }, function (e) {
        return dispatch(startQueryError(e));
      });
    };
  };

  var stopQueryStart = function stopQueryStart() {
    return { type: STOP_QUERY_START };
  };
  var stopQueryError = function stopQueryError(err) {
    return defaultError(STOP_QUERY_ERROR, err);
  };
  var stopQuerySuccess = function stopQuerySuccess(res) {
    return defaultSuccess(STOP_QUERY_SUCCESS, res);
  };
  var stopQuery = function stopQuery(datasetId, queryId) {
    return function (dispatch) {
      dispatch(stopQueryStart());

      var apiMethod = isExternalForm ? api.deleteFormQuery : api.deleteQuery;

      return apiMethod(datasetId, queryId).then(function (r) {
        return dispatch(stopQuerySuccess(r));
      }, function (e) {
        return dispatch(stopQueryError(e));
      });
    };
  };

  var queryResultStart = function queryResultStart() {
    return { type: QUERY_RESULT_START };
  };
  var queryResultStop = function queryResultStop() {
    return { type: QUERY_RESULT_STOP };
  };
  var queryResultError = function queryResultError(err) {
    return defaultError(QUERY_RESULT_ERROR, err);
  };
  var queryResultSuccess = function queryResultSuccess(res) {
    return defaultSuccess(QUERY_RESULT_SUCCESS, res);
  };
  var queryResult = function queryResult(datasetId, queryId) {
    return function (dispatch) {
      dispatch(queryResultStart());

      var apiMethod = isExternalForm ? api.getFormQuery : api.getQuery;

      return apiMethod(datasetId, queryId).then(function (r) {
        // Indicate that looking for the result has stopped,
        // but not necessarily succeeded
        dispatch(queryResultStop());

        if (r.status === 'DONE') {
          dispatch(queryResultSuccess(r));

          // Now there should be a new result that can be queried
          dispatch(loadPreviousQueries(datasetId));
        } else if (r.status === 'CANCELED' || r.status === 'FAILED') {
          dispatch(queryResultError(r));
        } else {
          // Try again after a short time:
          //   Use the "long polling" strategy, where we assume that the
          //   backend blocks the request for a couple of seconds and waits
          //   for the query comes back.
          //   If it doesn't come back the request resolves and
          //   we - the frontend - try again almost instantly.
          setTimeout(function () {
            return dispatch(queryResult(datasetId, queryId));
          }, QUERY_AGAIN_TIMEOUT);
        }
      }, function (e) {
        return dispatch(queryResultError(e));
      });
    };
  };

  return _ref = {}, _defineProperty(_ref, 'start' + capitalizedType + 'QueryStart', startQueryStart), _defineProperty(_ref, 'start' + capitalizedType + 'QueryError', startQueryError), _defineProperty(_ref, 'start' + capitalizedType + 'QuerySuccess', startQuerySuccess), _defineProperty(_ref, 'start' + capitalizedType + 'Query', startQuery), _defineProperty(_ref, 'stop' + capitalizedType + 'QueryStart', stopQueryStart), _defineProperty(_ref, 'stop' + capitalizedType + 'QueryError', stopQueryError), _defineProperty(_ref, 'stop' + capitalizedType + 'QuerySuccess', stopQuerySuccess), _defineProperty(_ref, 'stop' + capitalizedType + 'Query', stopQuery), _defineProperty(_ref, 'query' + capitalizedType + 'ResultStart', queryResultStart), _defineProperty(_ref, 'query' + capitalizedType + 'ResultStop', queryResultStop), _defineProperty(_ref, 'query' + capitalizedType + 'ResultError', queryResultError), _defineProperty(_ref, 'query' + capitalizedType + 'ResultSuccess', queryResultSuccess), _defineProperty(_ref, 'query' + capitalizedType + 'Result', queryResult), _ref;
}
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(createQueryRunnerActions, 'createQueryRunnerActions', '/home/travis/build/bakdata/conquery/frontend/lib/js/query-runner/actions.js');
  leaveModule(module);
})();

;