var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

import T from 'i18n-react';
import { toUpperCaseUnderscore } from '../common/helpers';
import * as actionTypes from './actionTypes';

export default function createQueryRunnerReducer(type) {
  var initialState = {
    runningQuery: null,
    queryRunning: false,
    startQuery: Object,
    stopQuery: Object,
    queryResult: Object
  };

  var capitalType = toUpperCaseUnderscore(type);

  // Example1: START_STANDARD_QUERY_START
  // Example2: START_TIMEBASED_QUERY_START
  var START_QUERY_START = actionTypes['START_' + capitalType + '_QUERY_START'];
  var START_QUERY_SUCCESS = actionTypes['START_' + capitalType + '_QUERY_SUCCESS'];
  var START_QUERY_ERROR = actionTypes['START_' + capitalType + '_QUERY_ERROR'];
  var STOP_QUERY_START = actionTypes['STOP_' + capitalType + '_QUERY_START'];
  var STOP_QUERY_SUCCESS = actionTypes['STOP_' + capitalType + '_QUERY_SUCCESS'];
  var STOP_QUERY_ERROR = actionTypes['STOP_' + capitalType + '_QUERY_ERROR'];
  var QUERY_RESULT_START = actionTypes['QUERY_' + capitalType + '_RESULT_START'];
  var QUERY_RESULT_STOP = actionTypes['QUERY_' + capitalType + '_RESULT_STOP'];
  var QUERY_RESULT_SUCCESS = actionTypes['QUERY_' + capitalType + '_RESULT_SUCCESS'];
  var QUERY_RESULT_ERROR = actionTypes['QUERY_' + capitalType + '_RESULT_ERROR'];

  var getQueryResult = function getQueryResult(data) {
    if (data.status === 'CANCELED') return { loading: false, error: T.translate('queryRunner.queryFailed') };else if (data.status === 'FAILED') return { loading: false, error: T.translate('queryRunner.queryCanceled') };

    // E.G. STATUS DONE
    return {
      loading: false,
      resultCount: data.numberOfResults,
      resultUrl: data.resultUrl
    };
  };

  return function () {
    var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : initialState;
    var action = arguments[1];

    switch (action.type) {
      // To start a query
      case START_QUERY_START:
        return _extends({}, state, { stopQuery: {}, startQuery: { loading: true }, queryResult: {} });
      case START_QUERY_SUCCESS:
        return _extends({}, state, {
          runningQuery: action.payload.data.id,
          queryRunning: true,
          stopQuery: {},
          startQuery: { success: true }
        });
      case START_QUERY_ERROR:
        return _extends({}, state, { stopQuery: {}, startQuery: { error: action.payload.message } });

      // To cancel a query
      case STOP_QUERY_START:
        return _extends({}, state, { startQuery: {}, stopQuery: { loading: true } });
      case STOP_QUERY_SUCCESS:
        return _extends({}, state, {
          runningQuery: null,
          queryRunning: false,
          startQuery: {},
          stopQuery: { success: true }
        });
      case STOP_QUERY_ERROR:
        return _extends({}, state, { startQuery: {}, stopQuery: { error: action.payload.message } });

      // To check for query results
      case QUERY_RESULT_START:
        return _extends({}, state, { queryResult: { loading: true } });
      case QUERY_RESULT_STOP:
        return _extends({}, state, { queryResult: { loading: false } });
      case QUERY_RESULT_SUCCESS:
        var data = action.payload.data;


        var _queryResult = getQueryResult(data);

        return _extends({}, state, {
          queryResult: _queryResult,
          runningQuery: null,
          queryRunning: false
        });
      case QUERY_RESULT_ERROR:
        return _extends({}, state, {
          runningQuery: null,
          queryRunning: false,
          queryResult: {
            loading: false,
            error: action.payload.message
          }
        });
      default:
        return state;
    }
  };
};
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(createQueryRunnerReducer, 'createQueryRunnerReducer', '/home/travis/build/bakdata/conquery/frontend/lib/js/query-runner/reducer.js');
  leaveModule(module);
})();

;