var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

import React from 'react';
import { connect } from 'react-redux';

import T from 'i18n-react';
import { replace } from 'react-router-redux';

import { toQuery } from '../routes';
import { queryGroupModalSetNode as _queryGroupModalSetNode } from '../query-group-modal/actions';
import { loadPreviousQuery as _loadPreviousQuery, loadAllPreviousQueriesInGroups } from '../previous-queries/list/actions';
import { dropFiles as _dropFiles, dropFilesDateRangeType as _dropFilesDateRangeType, dropFilesAndIdx as _dropFilesAndIdx } from '../file-upload/actions';


import { dropAndNode as _dropAndNode, dropOrNode as _dropOrNode, deleteNode as _deleteNode, deleteGroup as _deleteGroup, toggleExcludeGroup as _toggleExcludeGroup, expandPreviousQuery as _expandPreviousQuery, selectNodeForEditing as _selectNodeForEditing } from './actions';

import { QueryEditorDropzone } from './QueryEditorDropzone';
import QueryGroup from './QueryGroup';

var Query = function Query(props) {
  return React.createElement(
    'div',
    { className: 'query-editor__query-container' },
    props.isEmptyQuery &&
    // Render a large Dropzone
    React.createElement(QueryEditorDropzone, {
      isInitial: true,
      onDropNode: function onDropNode(item) {
        return props.dropAndNode(item);
      },
      onDropFiles: props.dropFiles,
      onLoadPreviousQuery: props.loadPreviousQuery
    }),
    React.createElement(
      'div',
      { className: 'query-editor__query' },
      !props.isEmptyQuery &&
      // Render all query groups plus individual AND / OR dropzones
      props.query.map(function (group, andIdx) {
        return [React.createElement(QueryGroup, {
          key: andIdx,
          group: group,
          andIdx: andIdx,
          onDropNode: function onDropNode(item) {
            return props.dropOrNode(item, andIdx);
          },
          onDropFiles: function onDropFiles(item) {
            return props.dropFilesAndIdx(item, andIdx);
          },
          onDeleteNode: function onDeleteNode(orIdx) {
            return props.deleteNode(andIdx, orIdx);
          },
          onDeleteGroup: function onDeleteGroup(orIdx) {
            return props.deleteGroup(andIdx, orIdx);
          },
          onFilterClick: function onFilterClick(orIdx) {
            return props.selectNodeForEditing(andIdx, orIdx);
          },
          onExpandClick: props.expandPreviousQuery,
          onExcludeClick: function onExcludeClick() {
            return props.toggleExcludeGroup(andIdx);
          },
          onDateClick: function onDateClick() {
            return props.queryGroupModalSetNode(andIdx);
          },
          onLoadPreviousQuery: props.loadPreviousQuery
        }), React.createElement(
          'p',
          { key: andIdx + '.and', className: 'query-group-connector' },
          T.translate('common.and')
        )];
      }).concat(React.createElement(
        'div',
        {
          className: 'dropzone-wrap',
          key: props.query.length + 1
        },
        React.createElement(QueryEditorDropzone, {
          isAnd: true,
          onDropNode: function onDropNode(item) {
            return props.dropAndNode(item, props.dateRange);
          },
          onDropFiles: function onDropFiles(item) {
            return props.dropFilesDateRangeType(item, props.dateRange);
          },
          onLoadPreviousQuery: props.loadPreviousQuery
        })
      ))
    )
  );
};

function mapStateToProps(state) {
  return {
    query: state.panes.right.tabs.queryEditor.query,
    isEmptyQuery: state.panes.right.tabs.queryEditor.query.length === 0,

    // only used by other actions
    rootConcepts: state.categoryTrees.trees
  };
}

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {
    dropAndNode: function dropAndNode(item, dateRange) {
      return dispatch(_dropAndNode(item, dateRange));
    },
    dropFiles: function dropFiles(item, type) {
      return dispatch(_dropFiles(item, type));
    },
    dropFilesDateRangeType: function dropFilesDateRangeType(item, dateRange) {
      return dispatch(_dropFilesDateRangeType(item, dateRange));
    },
    dropFilesAndIdx: function dropFilesAndIdx(item, andIdx) {
      return dispatch(_dropFilesAndIdx(item, andIdx));
    },
    dropOrNode: function dropOrNode(item, andIdx) {
      return dispatch(_dropOrNode(item, andIdx));
    },
    deleteNode: function deleteNode(andIdx, orIdx) {
      return dispatch(_deleteNode(andIdx, orIdx));
    },
    deleteGroup: function deleteGroup(andIdx, orIdx) {
      return dispatch(_deleteGroup(andIdx, orIdx));
    },
    toggleExcludeGroup: function toggleExcludeGroup(andIdx) {
      return dispatch(_toggleExcludeGroup(andIdx));
    },
    selectNodeForEditing: function selectNodeForEditing(andIdx, orIdx) {
      return dispatch(_selectNodeForEditing(andIdx, orIdx));
    },
    queryGroupModalSetNode: function queryGroupModalSetNode(andIdx) {
      return dispatch(_queryGroupModalSetNode(andIdx));
    },
    expandPreviousQuery: function expandPreviousQuery(datasetId, rootConcepts, groups, queryId) {
      dispatch(_expandPreviousQuery(rootConcepts, groups));

      dispatch(loadAllPreviousQueriesInGroups(groups, datasetId));

      dispatch(replace(toQuery(datasetId, queryId)));
    },
    loadPreviousQuery: function loadPreviousQuery(datasetId, queryId) {
      return dispatch(_loadPreviousQuery(datasetId, queryId));
    }
  };
};

var mergeProps = function mergeProps(stateProps, dispatchProps, ownProps) {
  return _extends({}, stateProps, dispatchProps, ownProps, {
    loadPreviousQuery: function loadPreviousQuery(queryId) {
      return dispatchProps.loadPreviousQuery(ownProps.selectedDatasetId, queryId);
    },
    expandPreviousQuery: function expandPreviousQuery(groups, queryId) {
      return dispatchProps.expandPreviousQuery(ownProps.selectedDatasetId, stateProps.rootConcepts, groups, queryId);
    }
  });
};

var _default = connect(mapStateToProps, mapDispatchToProps, mergeProps)(Query);

export default _default;
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(Query, 'Query', '/home/travis/build/bakdata/conquery/frontend/lib/js/standard-query-editor/Query.js');
  reactHotLoader.register(mapStateToProps, 'mapStateToProps', '/home/travis/build/bakdata/conquery/frontend/lib/js/standard-query-editor/Query.js');
  reactHotLoader.register(mapDispatchToProps, 'mapDispatchToProps', '/home/travis/build/bakdata/conquery/frontend/lib/js/standard-query-editor/Query.js');
  reactHotLoader.register(mergeProps, 'mergeProps', '/home/travis/build/bakdata/conquery/frontend/lib/js/standard-query-editor/Query.js');
  reactHotLoader.register(_default, 'default', '/home/travis/build/bakdata/conquery/frontend/lib/js/standard-query-editor/Query.js');
  leaveModule(module);
})();

;