(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

import api from '../api';

import { expandPreviousQuery } from '../standard-query-editor/actions';
import { loadAllPreviousQueriesInGroups } from '../previous-queries/list/actions';
import { loadDatasets, selectDatasetInput } from '../dataset/actions';
import { defaultError, defaultSuccess } from '../common/actions';

import { LOAD_CONFIG_START, LOAD_CONFIG_ERROR, LOAD_CONFIG_SUCCESS } from './actionTypes';

export var startupOnDataset = function startupOnDataset(datasetId) {
  return loadDatasets(datasetId);
};

export var startupOnQuery = function startupOnQuery(datasetId, queryId) {
  return function (dispatch) {
    return dispatch(loadDatasets(datasetId)).then(function (concepts) {
      if (!concepts) return;

      return api.getStoredQuery(datasetId, queryId).then(function (storedQuery) {
        dispatch(expandPreviousQuery(concepts, storedQuery.query.groups));
        dispatch(loadAllPreviousQueriesInGroups(storedQuery.query.groups, datasetId));
      }, function (e) {
        return dispatch(selectDatasetInput(datasetId));
      });
    });
  };
};

export var loadConfigStart = function loadConfigStart() {
  return { type: LOAD_CONFIG_START };
};
export var loadConfigError = function loadConfigError(err) {
  return defaultError(LOAD_CONFIG_ERROR, err);
};
export var loadConfigSuccess = function loadConfigSuccess(res) {
  return defaultSuccess(LOAD_CONFIG_SUCCESS, res);
};

export var loadConfig = function loadConfig() {
  return function (dispatch) {
    dispatch(loadConfigStart());

    return api.getFrontendConfig().then(function (r) {
      return dispatch(loadConfigSuccess(r));
    }, function (e) {
      return dispatch(loadConfigError(e));
    });
  };
};
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(startupOnDataset, 'startupOnDataset', '/home/travis/build/bakdata/conquery/frontend/lib/js/startup/actions.js');
  reactHotLoader.register(startupOnQuery, 'startupOnQuery', '/home/travis/build/bakdata/conquery/frontend/lib/js/startup/actions.js');
  reactHotLoader.register(loadConfigStart, 'loadConfigStart', '/home/travis/build/bakdata/conquery/frontend/lib/js/startup/actions.js');
  reactHotLoader.register(loadConfigError, 'loadConfigError', '/home/travis/build/bakdata/conquery/frontend/lib/js/startup/actions.js');
  reactHotLoader.register(loadConfigSuccess, 'loadConfigSuccess', '/home/travis/build/bakdata/conquery/frontend/lib/js/startup/actions.js');
  reactHotLoader.register(loadConfig, 'loadConfig', '/home/travis/build/bakdata/conquery/frontend/lib/js/startup/actions.js');
  leaveModule(module);
})();

;