(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

import React from 'react';
import T from 'i18n-react';
import classnames from 'classnames';
import { DragSource } from 'react-dnd';

import { VerticalToggleButton } from '../form-components';
import { FIRST, LAST, RANDOM } from '../common/constants/timebasedQueryTimestampTypes';
import { TIMEBASED_NODE } from '../common/constants/dndTypes';

var TimebasedNode = function TimebasedNode(props) {
  var toggleButton = React.createElement(VerticalToggleButton, {
    onToggle: props.onSetTimebasedNodeTimestamp,
    activeValue: props.node.timestamp,
    options: [{ label: T.translate('timebasedQueryEditor.timestampFirst'), value: FIRST }, { label: T.translate('timebasedQueryEditor.timestampRandom'), value: RANDOM }, { label: T.translate('timebasedQueryEditor.timestampLast'), value: LAST }]
  });

  return props.connectDragSource(React.createElement(
    'div',
    { className: classnames("timebased-node", 'timebased-node--' + props.position) },
    React.createElement(
      'div',
      { className: 'timebased-node__container' },
      React.createElement(
        'div',
        { className: 'timebased-node__content' },
        React.createElement(
          'div',
          { className: 'timebased-node__timestamp' },
          React.createElement(
            'p',
            { className: 'timebased-node__timestamp__title' },
            T.translate('timebasedQueryEditor.timestamp')
          ),
          toggleButton
        ),
        React.createElement(
          'div',
          { className: 'timebased-node__description' },
          React.createElement(
            'span',
            {
              onClick: props.onRemove,
              className: 'timebased-condition__remove-btn btn btn--small btn--icon'
            },
            React.createElement('i', { className: 'fa fa-close' })
          ),
          React.createElement(
            'p',
            { className: 'timebased-node__description__text' },
            props.node.label || props.node.id
          )
        )
      ),
      React.createElement(
        'button',
        {
          className: classnames("timebased-node__index-result-btn", {
            "timebased-node__index-result-btn--active": props.isIndexResult,
            "timebased-node__index-result-btn--disabled": props.isIndexResultDisabled
          }),
          disabled: props.isIndexResultDisabled,
          onClick: props.onSetTimebasedIndexResult
        },
        T.translate('timebasedQueryEditor.timestampResultsFrom')
      )
    )
  ));
};

/**
 * Implements the drag source contract.
 */
var nodeSource = {
  beginDrag: function beginDrag(props) {
    // Return the data describing the dragged item
    var node = props.node,
        conditionIdx = props.conditionIdx,
        resultIdx = props.resultIdx;


    return {
      conditionIdx: conditionIdx,
      resultIdx: resultIdx,
      node: node,
      moved: true
    };
  }
};

/**
 * Specifies the dnd-related props to inject into the component.
 */
function collect(connect, monitor) {
  return {
    connectDragSource: connect.dragSource(),
    isDragging: monitor.isDragging()
  };
}

var DraggableTimebasedNode = DragSource(TIMEBASED_NODE, nodeSource, collect)(TimebasedNode);

var _default = DraggableTimebasedNode;
export default _default;
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(TimebasedNode, 'TimebasedNode', '/home/travis/build/bakdata/conquery/frontend/lib/js/timebased-query-editor/TimebasedNode.js');
  reactHotLoader.register(nodeSource, 'nodeSource', '/home/travis/build/bakdata/conquery/frontend/lib/js/timebased-query-editor/TimebasedNode.js');
  reactHotLoader.register(collect, 'collect', '/home/travis/build/bakdata/conquery/frontend/lib/js/timebased-query-editor/TimebasedNode.js');
  reactHotLoader.register(DraggableTimebasedNode, 'DraggableTimebasedNode', '/home/travis/build/bakdata/conquery/frontend/lib/js/timebased-query-editor/TimebasedNode.js');
  reactHotLoader.register(_default, 'default', '/home/travis/build/bakdata/conquery/frontend/lib/js/timebased-query-editor/TimebasedNode.js');
  leaveModule(module);
})();

;