(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

import { connect } from 'react-redux';
import 'redux-thunk';

import { isEmpty } from '../common/helpers';
import * as actions from './actions';
import HoverableBase from './HoverableBase';

// Whitelist the data we pass (especially: don't pass all children)
var additionalInfos = function additionalInfos(node) {
  return {
    label: node.label,
    description: node.description,
    matchingEntries: node.matchingEntries,
    dateRange: node.dateRange,
    additionalInfos: node.additionalInfos
  };
};

// Decorates a component with a hoverable node.
// On mouse enter, additional infos about the component are saved in the state
// The Tooltip (and potential other components) might then update their view.
// On mouse leave, the infos are cleared from the state again
var AdditionalInfoHoverable = function AdditionalInfoHoverable(Component) {
  var mapStateToProps = function mapStateToProps() {
    return {};
  };

  var mapDispatchToProps = function mapDispatchToProps(dispatch, ownProps) {
    return {
      onDisplayAdditionalInfos: function onDisplayAdditionalInfos() {
        var node = ownProps.node;

        if (!node.additionalInfos && isEmpty(node.matchingEntries)) return;

        dispatch(actions.displayAdditionalInfos(additionalInfos(node)));
      },
      onToggleAdditionalInfos: function onToggleAdditionalInfos() {
        var node = ownProps.node;

        if (!node.additionalInfos && isEmpty(node.matchingEntries)) return;

        dispatch([actions.toggleAdditionalInfos(additionalInfos(node)), actions.displayAdditionalInfos(additionalInfos(node))]);
      }
    };
  };

  return connect(mapStateToProps, mapDispatchToProps)(HoverableBase(Component));
};

var _default = AdditionalInfoHoverable;
export default _default;
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(additionalInfos, 'additionalInfos', '/home/travis/build/bakdata/conquery/frontend/lib/js/tooltip/AdditionalInfoHoverable.js');
  reactHotLoader.register(AdditionalInfoHoverable, 'AdditionalInfoHoverable', '/home/travis/build/bakdata/conquery/frontend/lib/js/tooltip/AdditionalInfoHoverable.js');
  reactHotLoader.register(_default, 'default', '/home/travis/build/bakdata/conquery/frontend/lib/js/tooltip/AdditionalInfoHoverable.js');
  leaveModule(module);
})();

;