(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

import React from 'react';
import classnames from 'classnames';

import T from 'i18n-react';
import { connect } from 'react-redux';
import Markdown from 'react-markdown';
import Highlighter from 'react-highlight-words';

import { IconButton } from '../button';
import { SearchType } from '../category-trees/reducer';

import ActivateTooltip from './ActivateTooltip';
import { toggleDisplayTooltip as _toggleDisplayTooltip } from './actions';

import TooltipEntries from './TooltipEntries';

var Tooltip = function Tooltip(props) {
  if (!props.displayTooltip) return React.createElement(ActivateTooltip, null);

  var additionalInfos = props.additionalInfos,
      toggleDisplayTooltip = props.toggleDisplayTooltip,
      toggleAdditionInfos = props.toggleAdditionInfos;
  var label = additionalInfos.label,
      description = additionalInfos.description,
      infos = additionalInfos.infos,
      matchingEntries = additionalInfos.matchingEntries,
      dateRange = additionalInfos.dateRange;

  var searchHighlight = function searchHighlight(text) {
    return React.createElement(Highlighter, {
      searchWords: props.search.words || [],
      autoEscape: true,
      textToHighlight: text || ''
    });
  };

  return React.createElement(
    'div',
    { className: 'tooltip' },
    toggleAdditionInfos && React.createElement('i', { className: 'tooltip__tack fa fa-thumb-tack' }),
    React.createElement(
      'div',
      { className: 'tooltip__left' },
      React.createElement(
        'div',
        null,
        !label && !description && React.createElement(
          'p',
          { className: 'tooltip__placeholder' },
          T.translate('tooltip.placeholder')
        ),
        React.createElement(
          'h3',
          { className: 'tooltip__headline' },
          searchHighlight(label),
          ' ',
          description && React.createElement(
            'span',
            null,
            ' - ',
            searchHighlight(description)
          )
        ),
        infos && infos.map(function (info, i) {
          return React.createElement(
            'div',
            { className: 'tooltip-info', key: i },
            React.createElement(
              'h3',
              { className: 'tooltip-info__key' },
              searchHighlight(info.key)
            ),
            React.createElement(Markdown, { className: 'tooltip-info__value',
              source: info.value,
              escapeHtml: true,
              renderers: { text: searchHighlight }
            })
          );
        })
      )
    ),
    React.createElement(TooltipEntries, {
      className: 'tooltip__right',
      matchingEntries: matchingEntries,
      dateRange: dateRange
    }),
    React.createElement(IconButton, {
      onClick: toggleDisplayTooltip,
      label: T.translate('tooltip.hide'),
      className: classnames('btn', 'btn--transparent', 'btn--transparent--light', 'btn--tiny', 'tooltip__btn', 'tooltip__btn--hide'),
      iconClassName: 'fa-angle-down'
    })
  );
};

var mapStateToProps = function mapStateToProps(state) {
  return {
    additionalInfos: state.tooltip.additionalInfos,
    displayTooltip: state.tooltip.displayTooltip,
    toggleAdditionInfos: state.tooltip.toggleAdditionInfos,
    search: state.categoryTrees.search
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {
    toggleDisplayTooltip: function toggleDisplayTooltip() {
      return dispatch(_toggleDisplayTooltip());
    }
  };
};

var _default = connect(mapStateToProps, mapDispatchToProps)(Tooltip);

export default _default;
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(Tooltip, 'Tooltip', '/home/travis/build/bakdata/conquery/frontend/lib/js/tooltip/Tooltip.js');
  reactHotLoader.register(mapStateToProps, 'mapStateToProps', '/home/travis/build/bakdata/conquery/frontend/lib/js/tooltip/Tooltip.js');
  reactHotLoader.register(mapDispatchToProps, 'mapDispatchToProps', '/home/travis/build/bakdata/conquery/frontend/lib/js/tooltip/Tooltip.js');
  reactHotLoader.register(_default, 'default', '/home/travis/build/bakdata/conquery/frontend/lib/js/tooltip/Tooltip.js');
  leaveModule(module);
})();

;