(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

import React from 'react';
import T from 'i18n-react';
import classnames from 'classnames';
import { formatDate, numberToThreeDigitArray } from '../common/helpers';

var _renderMatchingEntriesTooltip = function _renderMatchingEntriesTooltip(matchingEntries) {
  return React.createElement(
    'span',
    null,
    React.createElement('i', { className: 'tooltip-entries__icon fa fa-bar-chart' }),
    React.createElement(
      'div',
      { className: 'tooltip-entries__info' },
      React.createElement(
        'p',
        { className: 'tooltip-entries__number' },
        numberToThreeDigitArray(matchingEntries).map(function (threeDigits, i) {
          return React.createElement(
            'span',
            { key: i, className: 'tooltip-entries__digits' },
            threeDigits
          );
        })
      ),
      React.createElement(
        'p',
        { className: 'tooltip-entries__text' },
        T.translate('tooltip.entriesFound', { context: matchingEntries // For pluralization
        })
      )
    )
  );
};

var _renderConceptDateRangeTooltip = function _renderConceptDateRangeTooltip(dateRange) {
  return React.createElement(
    'span',
    { style: { marginLeft: 36 } },
    React.createElement('i', { className: 'tooltip-entries__icon fa fa-calendar' }),
    React.createElement(
      'div',
      { className: 'tooltip-entries__info' },
      React.createElement(
        'div',
        { className: 'tooltip-entries__date-container' },
        React.createElement(
          'p',
          { className: 'tooltip-entries__date' },
          T.translate('tooltip.date.from') + ":"
        ),
        React.createElement(
          'p',
          { className: 'tooltip-entries__date' },
          T.translate('tooltip.date.to') + ":"
        )
      ),
      React.createElement(
        'div',
        { className: 'tooltip-entries__date-container' },
        React.createElement(
          'p',
          { className: 'tooltip-entries__date' },
          formatDate(dateRange.lowerEndpoint)
        ),
        React.createElement(
          'p',
          { className: 'tooltip-entries__date' },
          formatDate(dateRange.upperEndpoint)
        )
      ),
      React.createElement(
        'p',
        { className: 'tooltip-entries__text' },
        T.translate('tooltip.date.daterange')
      )
    )
  );
};

var TooltipEntries = function TooltipEntries(props) {
  if (typeof props.matchingEntries === 'undefined' || props.matchingEntries === null) return null;

  return React.createElement(
    'div',
    { className: classnames(props.className, "tooltip-entries", {
        'tooltip-entries--zero': props.matchingEntries === 0
      }) },
    React.createElement(
      'div',
      { className: 'tooltip-entries__right-container' },
      _renderMatchingEntriesTooltip(props.matchingEntries),
      props.dateRange && _renderConceptDateRangeTooltip(props.dateRange)
    )
  );
};

var _default = TooltipEntries;
export default _default;
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(_renderMatchingEntriesTooltip, '_renderMatchingEntriesTooltip', '/home/travis/build/bakdata/conquery/frontend/lib/js/tooltip/TooltipEntries.js');
  reactHotLoader.register(_renderConceptDateRangeTooltip, '_renderConceptDateRangeTooltip', '/home/travis/build/bakdata/conquery/frontend/lib/js/tooltip/TooltipEntries.js');
  reactHotLoader.register(TooltipEntries, 'TooltipEntries', '/home/travis/build/bakdata/conquery/frontend/lib/js/tooltip/TooltipEntries.js');
  reactHotLoader.register(_default, 'default', '/home/travis/build/bakdata/conquery/frontend/lib/js/tooltip/TooltipEntries.js');
  leaveModule(module);
})();

;